@@ -1,10 +1,12 @@
 // Implementation of watches
 
 #include "zeek-config.h"
+#include "zeek/DbgWatch.h"
 
-#include "Debug.h"
-#include "DbgWatch.h"
-#include "Reporter.h"
+#include "zeek/Debug.h"
+#include "zeek/Reporter.h"
+
+namespace zeek::detail {
 
 // Support classes
 DbgWatch::DbgWatch(zeek::Obj* var_to_watch)
@@ -12,11 +14,9 @@ DbgWatch::DbgWatch(zeek::Obj* var_to_watch)
 	reporter->InternalError("DbgWatch unimplemented");
 	}
 
-DbgWatch::DbgWatch(zeek::detail::Expr* expr_to_watch)
+DbgWatch::DbgWatch(Expr* expr_to_watch)
 	{
 	reporter->InternalError("DbgWatch unimplemented");
 	}
 
-DbgWatch::~DbgWatch()
-	{
-	}
+} // namespace zeek::detail
