@@ -2,6 +2,7 @@
 // implementation of most commands.
 
 #include "zeek-config.h"
+#include "zeek/DebugCmds.h"
 
 #include <sys/types.h>
 
@@ -9,28 +10,39 @@
 #include <string.h>
 #include <assert.h>
 
-#include "Debug.h"
-#include "DebugCmds.h"
-#include "DebugCmdInfoConstants.cc"
-#include "DbgBreakpoint.h"
-#include "Func.h"
-#include "Stmt.h"
-#include "Scope.h"
-#include "PolicyFile.h"
-#include "util.h"
+#include "zeek/DebugCmdInfoConstants.cc"
+#include "zeek/Debug.h"
+#include "zeek/Desc.h"
+#include "zeek/DbgBreakpoint.h"
+#include "zeek/ID.h"
+#include "zeek/Frame.h"
+#include "zeek/Func.h"
+#include "zeek/Stmt.h"
+#include "zeek/Scope.h"
+#include "zeek/Reporter.h"
+#include "zeek/PolicyFile.h"
+#include "zeek/Val.h"
+#include "zeek/util.h"
+
+using namespace std;
+
+zeek::PQueue<zeek::detail::DebugCmdInfo> zeek::detail::g_DebugCmdInfos;
+zeek::PQueue<zeek::detail::DebugCmdInfo>& g_DebugCmdInfos = zeek::detail::g_DebugCmdInfos;
+
+namespace zeek::detail {
 
 //
 // Helper routines
 //
-bool string_is_regex(string s)
+static bool string_is_regex(const string& s)
 	{
-	return strpbrk(s.c_str(), "?*\\+");
+	return strpbrk(s.data(), "?*\\+");
 	}
 
-void lookup_global_symbols_regex(const string& orig_regex, vector<ID*>& matches,
-					bool func_only = false)
+static void lookup_global_symbols_regex(const string& orig_regex, vector<ID*>& matches,
+                                        bool func_only = false)
 	{
-	if ( streq(orig_regex.c_str(), "") )
+	if ( util::streq(orig_regex.c_str(), "") )
 		return;
 
 	string regex = "^";
@@ -51,30 +63,32 @@ void lookup_global_symbols_regex(const string& orig_regex, vector<ID*>& matches,
 		}
 
 	Scope* global = global_scope();
-	PDict<ID>* syms = global->Vars();
+	const auto& syms = global->Vars();
 
 	ID* nextid;
-	IterCookie* cookie = syms->InitForIteration();
-	while ( (nextid = syms->NextEntry( cookie )) )
-		if ( ! func_only || nextid->Type()->Tag() == TYPE_FUNC )
+	for ( const auto& sym : syms )
+		{
+		ID* nextid = sym.second.get();
+		if ( ! func_only || nextid->GetType()->Tag() == TYPE_FUNC )
 			if ( ! regexec (&re, nextid->Name(), 0, 0, 0) )
 				matches.push_back(nextid);
+		}
 	}
 
-void choose_global_symbols_regex(const string& regex, vector<ID*>& choices,
-					bool func_only = false)
+static void choose_global_symbols_regex(const string& regex, vector<ID*>& choices,
+                                        bool func_only = false)
 	{
 	lookup_global_symbols_regex(regex, choices, func_only);
 
 	if ( choices.size() <= 1 )
 		return;
 
-	while ( 1 )
+	while ( true )
 		{
 		debug_msg("There were multiple matches, please choose:\n");
 
-		for ( unsigned int i = 0; i < choices.size(); ++i )
-			debug_msg("[%d] %s\n", i+1, choices[i]->Name());
+		for ( size_t i = 0; i < choices.size(); i++ )
+			debug_msg("[%zu] %s\n", i+1, choices[i]->Name());
 
 		debug_msg("[a] All of the above\n");
 		debug_msg("[n] None of the above\n");
@@ -114,10 +128,8 @@ void choose_global_symbols_regex(const string& regex, vector<ID*>& choices,
 // DebugCmdInfo implementation
 //
 
-PQueue<DebugCmdInfo> g_DebugCmdInfos;
-
 DebugCmdInfo::DebugCmdInfo(const DebugCmdInfo& info)
-: cmd(info.cmd), helpstring(0)
+: cmd(info.cmd), helpstring(nullptr)
 	{
 	num_names = info.num_names;
 	names = info.names;
@@ -145,7 +157,7 @@ const DebugCmdInfo* get_debug_cmd_info(DebugCmd cmd)
 	if ( (int) cmd < g_DebugCmdInfos.length() )
 		return g_DebugCmdInfos[(int) cmd];
 	else
-		return 0;
+		return nullptr;
 	}
 
 int find_all_matching_cmds(const string& prefix, const char* array_of_matches[])
@@ -157,7 +169,7 @@ int find_all_matching_cmds(const string& prefix, const char* array_of_matches[])
 
 	for ( int i = 0; i < num_debug_cmds(); ++i )
 		{
-		array_of_matches[g_DebugCmdInfos[i]->Cmd()] = 0;
+		array_of_matches[g_DebugCmdInfos[i]->Cmd()] = nullptr;
 
 		for ( int j = 0; j < g_DebugCmdInfos[i]->NumNames(); ++j )
 			{
@@ -169,7 +181,7 @@ int find_all_matching_cmds(const string& prefix, const char* array_of_matches[])
 			if ( ! prefix.compare(curr_name) )
 				{
 				for ( int k = 0; k < num_debug_cmds(); ++k )
-					array_of_matches[k] = 0;
+					array_of_matches[k] = nullptr;
 
 				array_of_matches[g_DebugCmdInfos[i]->Cmd()] = curr_name;
 				return 1;
@@ -206,7 +218,7 @@ static int dbg_backtrace_internal(int start, int end)
 	for ( int i = start; i >= end; --i )
 		{
 		const Frame* f = g_frame_stack[i];
-		const Stmt* stmt = f ? f->GetNextStmt() : 0;
+		const Stmt* stmt = f ? f->GetNextStmt() : nullptr;
 
 		string context = get_context_description(stmt, f);
 		debug_msg("#%d  %s\n",
@@ -357,7 +369,7 @@ int dbg_cmd_break(DebugCmd cmd, const vector<string>& args)
 
 	int cond_index = -1; // at which argument pos. does bp condition start?
 
-	if ( args.size() == 0 || args[0] == "if" )
+	if ( args.empty() || args[0] == "if" )
 		{ // break on next stmt
 		int user_frame_number =
 			g_frame_stack.size() - 1 -
@@ -403,11 +415,11 @@ int dbg_cmd_break(DebugCmd cmd, const vector<string>& args)
 				  locstrings[strindex].c_str());
 			vector<ParseLocationRec> plrs =
 				parse_location_string(locstrings[strindex]);
-			for ( unsigned int i = 0; i < plrs.size(); ++i )
+			for ( const auto& plr : plrs )
 				{
 				DbgBreakpoint* bp = new DbgBreakpoint();
 				bp->SetID(g_debugger_state.NextBPID());
-				if ( ! bp->SetLocation(plrs[i], locstrings[strindex]) )
+				if ( ! bp->SetLocation(plr, locstrings[strindex]) )
 					{
 					debug_msg("Breakpoint not set.\n");
 					delete bp;
@@ -422,22 +434,22 @@ int dbg_cmd_break(DebugCmd cmd, const vector<string>& args)
 		}
 
 	// Is there a condition specified?
-	if ( cond_index >= 0 && bps.size() )
+	if ( cond_index >= 0 && ! bps.empty() )
 		{
 		// ### Implement conditions
 		string cond;
-		for ( int i = cond_index; i < int(args.size()); ++i )
+		for ( const auto& arg : args )
 			{
-			cond += args[i];
+			cond += arg;
 			cond += "    ";
 			}
 		bps[0]->SetCondition(cond);
 		}
 
-	for ( unsigned int i = 0; i < bps.size(); ++i )
+	for ( auto& bp : bps )
 		{
-		bps[i]->SetTemporary(false);
-		g_debugger_state.breakpoints[bps[i]->GetID()] = bps[i];
+		bp->SetTemporary(false);
+		g_debugger_state.breakpoints[bp->GetID()] = bp;
 		}
 
 	return 0;
@@ -481,7 +493,7 @@ int dbg_cmd_break_set_state(DebugCmd cmd, const vector<string>& args)
 		return 0;
 		}
 
-	if ( g_debugger_state.breakpoints.size() == 0 )
+	if ( g_debugger_state.breakpoints.empty() )
 		{
 		debug_msg ("No breakpoints currently set.\n");
 		return -1;
@@ -489,7 +501,7 @@ int dbg_cmd_break_set_state(DebugCmd cmd, const vector<string>& args)
 
 	vector<int> bps_to_change;
 
-	if ( args.size() == 0 )
+	if ( args.empty() )
 		{
 		BPIDMapType::iterator iter;
 		for ( iter = g_debugger_state.breakpoints.begin();
@@ -498,15 +510,13 @@ int dbg_cmd_break_set_state(DebugCmd cmd, const vector<string>& args)
 		}
 	else
 		{
-		for ( unsigned int i = 0; i < args.size(); ++i )
-			if ( int idx = atoi(args[i].c_str()) )
+		for ( const auto& arg : args )
+			if ( int idx = atoi(arg.c_str()) )
 				bps_to_change.push_back(idx);
 		}
 
-	for ( unsigned int i = 0; i < bps_to_change.size(); ++i )
+	for ( auto bp_change : bps_to_change )
 		{
-		int bp_change = bps_to_change[i];
-
 		BPIDMapType::iterator result =
 			g_debugger_state.breakpoints.find(bp_change);
 
@@ -550,14 +560,14 @@ int dbg_cmd_print(DebugCmd cmd, const vector<string>& args)
 
 	// Just concatenate all the 'args' into one expression.
 	string expr;
-	for ( int i = 0; i < int(args.size()); ++i )
+	for ( size_t i = 0; i < args.size(); ++i )
 		{
 		expr += args[i];
-		if ( i < int(args.size()) - 1 )
+		if ( i < args.size() - 1 )
 			expr += " ";
 		}
 
-	Val* val = dbg_eval_expr(expr.c_str());
+	auto val = dbg_eval_expr(expr.c_str());
 
 	if ( val )
 		{
@@ -580,7 +590,7 @@ int dbg_cmd_info(DebugCmd cmd, const vector<string>& args)
 	{
 	assert(cmd == dcInfo);
 
-	if ( ! args.size() )
+	if ( args.empty() )
 		{
 		debug_msg("Syntax: info info-command\n");
 		debug_msg("List of info-commands:\n");
@@ -628,7 +638,7 @@ int dbg_cmd_list(DebugCmd cmd, const vector<string>& args)
 		return 0;
 		}
 
-	if ( args.size() == 0 )
+	if ( args.empty() )
 		{
 		// Special case: if we just hit a breakpoint, then show
 		// that line without advancing first.
@@ -656,7 +666,7 @@ int dbg_cmd_list(DebugCmd cmd, const vector<string>& args)
 		{
 		vector<ParseLocationRec> plrs = parse_location_string(args[0]);
 		ParseLocationRec plr = plrs[0];
-		if ( plr.type == plrUnknown )
+		if ( plr.type == PLR_UNKNOWN )
 			{
 			debug_msg("Invalid location specifier\n");
 			return false;
@@ -693,7 +703,7 @@ int dbg_cmd_trace(DebugCmd cmd, const vector<string>& args)
 	{
 	assert(cmd == dcTrace);
 
-	if ( args.size() == 0 )
+	if ( args.empty() )
 		{
 		debug_msg("Execution tracing is %s.\n",
 		g_trace_state.DoTrace() ? "on" : "off" );
@@ -715,3 +725,5 @@ int dbg_cmd_trace(DebugCmd cmd, const vector<string>& args)
 	debug_msg("Invalid argument");
 	return 0;
 	}
+
+} // namespace zeek::detail
