@@ -1,22 +1,24 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
-#include "Desc.h"
+#include "zeek/Desc.h"
 
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
 #include <math.h>
 
-#include "File.h"
-#include "Reporter.h"
-#include "ConvertUTF.h"
-#include "IPAddr.h"
+#include "zeek/File.h"
+#include "zeek/Reporter.h"
+#include "zeek/ConvertUTF.h"
+#include "zeek/IPAddr.h"
 
 #define DEFAULT_SIZE 128
 #define SLOP 10
 
-ODesc::ODesc(desc_type t, BroFile* arg_f)
+namespace zeek {
+
+ODesc::ODesc(DescType t, File* arg_f)
 	{
 	type = t;
 	style = STANDARD_STYLE;
@@ -25,7 +27,7 @@ ODesc::ODesc(desc_type t, BroFile* arg_f)
 	if ( f == nullptr )
 		{
 		size = DEFAULT_SIZE;
-		base = safe_malloc(size);
+		base = util::safe_malloc(size);
 		((char*) base)[0] = '\0';
 		offset = 0;
 		}
@@ -197,7 +199,7 @@ void ODesc::AddCS(const char* s)
 	Add(s);
 	}
 
-void ODesc::AddBytes(const zeek::String* s)
+void ODesc::AddBytes(const String* s)
 	{
 	if ( IsReadable() )
 		{
@@ -205,7 +207,7 @@ void ODesc::AddBytes(const zeek::String* s)
 			AddBytes(reinterpret_cast<const char*>(s->Bytes()), s->Len());
 		else
 			{
-			const char* str = s->Render(zeek::String::EXPANDED_STRING);
+			const char* str = s->Render(String::EXPANDED_STRING);
 			Add(str);
 			delete [] str;
 			}
@@ -333,7 +335,7 @@ void ODesc::AddBytes(const void* bytes, unsigned int n)
 		if ( p.first )
 			{
 			AddBytesRaw(s, p.first - s);
-			get_escaped_string(this, p.first, p.second, true);
+			util::get_escaped_string(this, p.first, p.second, true);
 			s = p.first + p.second;
 			}
 		else
@@ -386,7 +388,7 @@ void ODesc::Grow(unsigned int n)
 	while ( offset + n + SLOP >= size )
 		size *= 2;
 
-	base = safe_realloc(base, size);
+	base = util::safe_realloc(base, size);
 	}
 
 void ODesc::Clear()
@@ -398,24 +400,24 @@ void ODesc::Clear()
 		{
 		free(base);
 		size = DEFAULT_SIZE;
-		base = safe_malloc(size);
+		base = util::safe_malloc(size);
 		((char*) base)[0] = '\0';
 		}
 	}
 
-bool ODesc::PushType(const zeek::Type* type)
+bool ODesc::PushType(const Type* type)
 	{
 	auto res = encountered_types.insert(type);
 	return std::get<1>(res);
 	}
 
-bool ODesc::PopType(const zeek::Type* type)
+bool ODesc::PopType(const Type* type)
 	{
 	size_t res = encountered_types.erase(type);
 	return (res == 1);
 	}
 
-bool ODesc::FindType(const zeek::Type* type)
+bool ODesc::FindType(const Type* type)
 	{
 	auto res = encountered_types.find(type);
 
@@ -424,3 +426,5 @@ bool ODesc::FindType(const zeek::Type* type)
 
 	return false;
 	}
+
+} // namespace zeek
