@@ -2,47 +2,50 @@
 
 #include "zeek-config.h"
 
-#include "Discard.h"
+#include "zeek/Discard.h"
 
 #include <algorithm>
 
-#include "Net.h"
-#include "Func.h"
-#include "Var.h"
-#include "Val.h"
-#include "IP.h"
-#include "Reporter.h" // for InterpreterException
+#include "zeek/ZeekString.h"
+#include "zeek/RunState.h"
+#include "zeek/Func.h"
+#include "zeek/Var.h"
+#include "zeek/Val.h"
+#include "zeek/IP.h"
+#include "zeek/Reporter.h" // for InterpreterException
+
+namespace zeek::detail {
 
 Discarder::Discarder()
 	{
-	check_ip = internal_func("discarder_check_ip");
-	check_tcp = internal_func("discarder_check_tcp");
-	check_udp = internal_func("discarder_check_udp");
-	check_icmp = internal_func("discarder_check_icmp");
+	check_ip = id::find_func("discarder_check_ip");
+	check_tcp = id::find_func("discarder_check_tcp");
+	check_udp = id::find_func("discarder_check_udp");
+	check_icmp = id::find_func("discarder_check_icmp");
 
-	discarder_maxlen = static_cast<int>(opt_internal_int("discarder_maxlen"));
+	discarder_maxlen = static_cast<int>(id::find_val("discarder_maxlen")->AsCount());
 	}
 
 Discarder::~Discarder()
 	{
 	}
 
-int Discarder::IsActive()
+bool Discarder::IsActive()
 	{
 	return check_ip || check_tcp || check_udp || check_icmp;
 	}
 
-int Discarder::NextPacket(const IP_Hdr* ip, int len, int caplen)
+bool Discarder::NextPacket(const std::unique_ptr<IP_Hdr>& ip, int len, int caplen)
 	{
-	int discard_packet = 0;
+	bool discard_packet = false;
 
 	if ( check_ip )
 		{
-		val_list args{ip->BuildPktHdrVal()};
+		zeek::Args args{ip->ToPktHdrVal()};
 
 		try
 			{
-			discard_packet = check_ip->Call(&args)->AsBool();
+			discard_packet = check_ip->Invoke(&args)->AsBool();
 			}
 
 		catch ( InterpreterException& e )
@@ -58,26 +61,26 @@ int Discarder::NextPacket(const IP_Hdr* ip, int len, int caplen)
 	if ( proto != IPPROTO_TCP && proto != IPPROTO_UDP &&
 	     proto != IPPROTO_ICMP )
 		// This is not a protocol we understand.
-		return 0;
+		return false;
 
 	// XXX shall we only check the first packet???
 	if ( ip->IsFragment() )
 		// Never check any fragment.
-		return 0;
+		return false;
 
 	int ip_hdr_len = ip->HdrLen();
 	len -= ip_hdr_len;	// remove IP header
 	caplen -= ip_hdr_len;
 
-	int is_tcp = (proto == IPPROTO_TCP);
-	int is_udp = (proto == IPPROTO_UDP);
+	bool is_tcp = (proto == IPPROTO_TCP);
+	bool is_udp = (proto == IPPROTO_UDP);
 	int min_hdr_len = is_tcp ?
 		sizeof(struct tcphdr) :
 		(is_udp ? sizeof(struct udphdr) : sizeof(struct icmp));
 
 	if ( len < min_hdr_len || caplen < min_hdr_len )
 		// we don't have a complete protocol header
-		return 0;
+		return false;
 
 	// Where the data starts - if this is a protocol we know about,
 	// this gets advanced past the transport header.
@@ -90,14 +93,14 @@ int Discarder::NextPacket(const IP_Hdr* ip, int len, int caplen)
 			const struct tcphdr* tp = (const struct tcphdr*) data;
 			int th_len = tp->th_off * 4;
 
-			val_list args{
-				ip->BuildPktHdrVal(),
-				BuildData(data, th_len, len, caplen),
+			zeek::Args args{
+				ip->ToPktHdrVal(),
+				{AdoptRef{}, BuildData(data, th_len, len, caplen)},
 			};
 
 			try
 				{
-				discard_packet = check_tcp->Call(&args)->AsBool();
+				discard_packet = check_tcp->Invoke(&args)->AsBool();
 				}
 
 			catch ( InterpreterException& e )
@@ -114,14 +117,14 @@ int Discarder::NextPacket(const IP_Hdr* ip, int len, int caplen)
 			const struct udphdr* up = (const struct udphdr*) data;
 			int uh_len = sizeof (struct udphdr);
 
-			val_list args{
-				ip->BuildPktHdrVal(),
-				BuildData(data, uh_len, len, caplen),
+			zeek::Args args{
+				ip->ToPktHdrVal(),
+				{AdoptRef{}, BuildData(data, uh_len, len, caplen)},
 			};
 
 			try
 				{
-				discard_packet = check_udp->Call(&args)->AsBool();
+				discard_packet = check_udp->Invoke(&args)->AsBool();
 				}
 
 			catch ( InterpreterException& e )
@@ -137,11 +140,11 @@ int Discarder::NextPacket(const IP_Hdr* ip, int len, int caplen)
 			{
 			const struct icmp* ih = (const struct icmp*) data;
 
-			val_list args{ip->BuildPktHdrVal()};
+			zeek::Args args{ip->ToPktHdrVal()};
 
 			try
 				{
-				discard_packet = check_icmp->Call(&args)->AsBool();
+				discard_packet = check_icmp->Invoke(&args)->AsBool();
 				}
 
 			catch ( InterpreterException& e )
@@ -160,7 +163,9 @@ Val* Discarder::BuildData(const u_char* data, int hdrlen, int len, int caplen)
 	caplen -= hdrlen;
 	data += hdrlen;
 
-	len = max(min(min(len, caplen), discarder_maxlen), 0);
+	len = std::max(std::min(std::min(len, caplen), discarder_maxlen), 0);
 
-	return new StringVal(new BroString(data, len, 1));
+	return new StringVal(new String(data, len, true));
 	}
+
+} // namespace zeek::detail
