@@ -2,8 +2,11 @@
 
 #include "zeek-config.h"
 
-#include "EquivClass.h"
-#include "CCL.h"
+#include "zeek/EquivClass.h"
+#include "zeek/CCL.h"
+#include "zeek/util.h"
+
+namespace zeek::detail {
 
 EquivClass::EquivClass(int arg_size)
 	{
@@ -186,5 +189,7 @@ void EquivClass::Dump(FILE* f)
 
 int EquivClass::Size() const
 	{
-	return padded_sizeof(*this) + pad_size(sizeof(int) * size * (ccl_flags ? 5 : 4));
+	return padded_sizeof(*this) + util::pad_size(sizeof(int) * size * (ccl_flags ? 5 : 4));
 	}
+
+} // namespace zeek::detail
