@@ -1,25 +1,25 @@
 #include "zeek-config.h"
+#include "zeek/PolicyFile.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <assert.h>
-
-#include <map>
 #include <stdio.h>
 #include <errno.h>
+
 #include <string>
 #include <vector>
+#include <map>
+
+#include "zeek/Debug.h"
+#include "zeek/util.h"
+#include "zeek/Reporter.h"
 
 using namespace std;
 
-#include "Debug.h"
-#include "util.h"
-#include "PolicyFile.h"
-#include "Reporter.h"
-
 struct PolicyFile {
-	PolicyFile ()	{ filedata = 0; lmtime = 0; }
-	~PolicyFile ()	{ delete [] filedata; filedata = 0; }
+	PolicyFile ()	{ filedata = nullptr; lmtime = 0; }
+	~PolicyFile ()	{ delete [] filedata; filedata = nullptr; }
 
 	time_t lmtime;
 	char* filedata;
@@ -29,6 +29,8 @@ struct PolicyFile {
 typedef map<string, PolicyFile*> PolicyFileMap;
 static PolicyFileMap policy_files;
 
+namespace zeek::detail {
+
 int how_many_lines_in(const char* policy_filename)
 	{
 	if ( ! policy_filename )
@@ -84,7 +86,7 @@ bool LoadPolicyFileText(const char* policy_filename)
 	if ( fstat(fileno(f), &st) != 0 )
 		{
 		char buf[256];
-		bro_strerror_r(errno, buf, sizeof(buf));
+		util::zeek_strerror_r(errno, buf, sizeof(buf));
 		reporter->Error("fstat failed on %s: %s", policy_filename, buf);
 		fclose(f);
 		return false;
@@ -174,3 +176,5 @@ bool PrintLines(const char* policy_filename, unsigned int start_line,
 
 	return true;
 	}
+
+} // namespace zeek::detail
