@@ -1,14 +1,16 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
-#include "Reassem.h"
+#include "zeek/Reassem.h"
 
 #include <algorithm>
 
-#include "Desc.h"
+#include "zeek/Desc.h"
 
 using std::min;
 
+namespace zeek {
+
 uint64_t Reassembler::total_size = 0;
 uint64_t Reassembler::sizes[REASSEM_NUM];
 
@@ -385,3 +387,4 @@ uint64_t Reassembler::MemoryAllocation(ReassemblerType rtype)
 	return Reassembler::sizes[rtype];
 	}
 
+} // namespace zeek
