@@ -1,9 +1,11 @@
 #include "zeek-config.h"
 
-#include "Rule.h"
-#include "RuleAction.h"
-#include "RuleCondition.h"
-#include "RuleMatcher.h"
+#include "zeek/Rule.h"
+#include "zeek/RuleAction.h"
+#include "zeek/RuleCondition.h"
+#include "zeek/RuleMatcher.h"
+
+namespace zeek::detail {
 
 // Start at one as we want search for this within a list,
 // and List's is_member returns zero for non-membership ...
@@ -73,7 +75,7 @@ void Rule::AddPattern(const char* str, Rule::PatternType type,
 			uint32_t offset, uint32_t depth)
 	{
 	Pattern* p = new Pattern;
-	p->pattern = copy_string(str);
+	p->pattern = util::copy_string(str);
 	p->type = type;
 	p->id = ++pattern_counter;
 	p->offset = offset;
@@ -86,8 +88,8 @@ void Rule::AddPattern(const char* str, Rule::PatternType type,
 void Rule::AddRequires(const char* id, bool opposite_direction, bool negate)
 	{
 	Precond* p = new Precond;
-	p->id = copy_string(id);
-	p->rule = 0;
+	p->id = util::copy_string(id);
+	p->rule = nullptr;
 	p->opposite_dir = opposite_direction;
 	p->negate = negate;
 
@@ -99,3 +101,5 @@ void Rule::SortHdrTests()
 	// FIXME: Do nothing for now - we may want to come up with
 	// something clever here.
 	}
+
+} // namespace zeek::detail
