@@ -1,37 +1,37 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
+#include "zeek/analyzer/protocol/finger/Finger.h"
 
 #include <ctype.h>
 
-#include "NetVar.h"
-#include "Finger.h"
-#include "Event.h"
-#include "analyzer/protocol/tcp/ContentLine.h"
+#include "zeek/NetVar.h"
+#include "zeek/Event.h"
+#include "zeek/analyzer/protocol/tcp/ContentLine.h"
 
-#include "events.bif.h"
+#include "analyzer/protocol/finger/events.bif.h"
 
-using namespace analyzer::finger;
+namespace zeek::analyzer::finger {
 
 Finger_Analyzer::Finger_Analyzer(Connection* conn)
-: tcp::TCP_ApplicationAnalyzer("FINGER", conn)
+: analyzer::tcp::TCP_ApplicationAnalyzer("FINGER", conn)
 	{
 	did_deliver = 0;
-	content_line_orig = new tcp::ContentLine_Analyzer(conn, true, 1000);
+	content_line_orig = new analyzer::tcp::ContentLine_Analyzer(conn, true, 1000);
 	content_line_orig->SetIsNULSensitive(true);
-	content_line_resp = new tcp::ContentLine_Analyzer(conn, false, 1000);
+	content_line_resp = new analyzer::tcp::ContentLine_Analyzer(conn, false, 1000);
 	AddSupportAnalyzer(content_line_orig);
 	AddSupportAnalyzer(content_line_resp);
 	}
 
 void Finger_Analyzer::Done()
 	{
-	tcp::TCP_ApplicationAnalyzer::Done();
+	analyzer::tcp::TCP_ApplicationAnalyzer::Done();
 
 	if ( TCP() )
 		if ( (! did_deliver || content_line_orig->HasPartialLine()) &&
-		     (TCP()->OrigState() == tcp::TCP_ENDPOINT_CLOSED ||
-		      TCP()->OrigPrevState() == tcp::TCP_ENDPOINT_CLOSED) )
+		     (TCP()->OrigState() == analyzer::tcp::TCP_ENDPOINT_CLOSED ||
+		      TCP()->OrigPrevState() == analyzer::tcp::TCP_ENDPOINT_CLOSED) )
 			// ### should include the partial text
 			Weird("partial_finger_request");
 	}
@@ -50,12 +50,12 @@ void Finger_Analyzer::DeliverStream(int length, const u_char* data, bool is_orig
 		if ( ! finger_request )
 			return;
 
-		line = skip_whitespace(line, end_of_line);
+		line = util::skip_whitespace(line, end_of_line);
 
 		// Check for /W.
 		int long_cnt = (line + 2 <= end_of_line && line[0] == '/' && toupper(line[1]) == 'W');
 		if ( long_cnt )
-			line = skip_whitespace(line+2, end_of_line);
+			line = util::skip_whitespace(line+2, end_of_line);
 
 		assert(line <= end_of_line);
 		size_t n = end_of_line >= line ? end_of_line - line : 0; // just to be sure if assertions aren't on.
@@ -69,13 +69,13 @@ void Finger_Analyzer::DeliverStream(int length, const u_char* data, bool is_orig
 		if ( finger_request )
 			EnqueueConnEvent(finger_request,
 				ConnVal(),
-				zeek::val_mgr->Bool(long_cnt),
-				zeek::make_intrusive<zeek::StringVal>(at - line, line),
-				zeek::make_intrusive<zeek::StringVal>(end_of_line - host, host)
+				val_mgr->Bool(long_cnt),
+				make_intrusive<StringVal>(at - line, line),
+				make_intrusive<StringVal>(end_of_line - host, host)
 			);
 
-		Conn()->Match(Rule::FINGER, (const u_char *) line,
-			  end_of_line - line, true, true, true, true);
+		Conn()->Match(zeek::detail::Rule::FINGER, (const u_char *) line,
+		              end_of_line - line, true, true, true, true);
 
 		did_deliver = 1;
 		}
@@ -87,7 +87,9 @@ void Finger_Analyzer::DeliverStream(int length, const u_char* data, bool is_orig
 
 		EnqueueConnEvent(finger_reply,
 			ConnVal(),
-			zeek::make_intrusive<zeek::StringVal>(end_of_line - line, line)
+			make_intrusive<StringVal>(end_of_line - line, line)
 		);
 		}
 	}
+
+} // namespace zeek::analyzer::finger
