@@ -1,14 +1,16 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "GSSAPI.h"
-#include "analyzer/protocol/tcp/TCP_Reassembler.h"
-#include "Reporter.h"
-#include "events.bif.h"
+#include "zeek/analyzer/protocol/gssapi/GSSAPI.h"
 
-using namespace analyzer::gssapi;
+#include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
+#include "zeek/Reporter.h"
+
+#include "analyzer/protocol/gssapi/events.bif.h"
+
+namespace zeek::analyzer::gssapi {
 
 GSSAPI_Analyzer::GSSAPI_Analyzer(Connection* c)
-	: tcp::TCP_ApplicationAnalyzer("GSSAPI", c)
+	: analyzer::tcp::TCP_ApplicationAnalyzer("GSSAPI", c)
 	{
 	interp = new binpac::GSSAPI::GSSAPI_Conn(this);
 	}
@@ -20,7 +22,7 @@ GSSAPI_Analyzer::~GSSAPI_Analyzer()
 
 void GSSAPI_Analyzer::Done()
 	{
-	tcp::TCP_ApplicationAnalyzer::Done();
+	analyzer::tcp::TCP_ApplicationAnalyzer::Done();
 
 	interp->FlowEOF(true);
 	interp->FlowEOF(false);
@@ -28,13 +30,13 @@ void GSSAPI_Analyzer::Done()
 
 void GSSAPI_Analyzer::EndpointEOF(bool is_orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::EndpointEOF(is_orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::EndpointEOF(is_orig);
 	interp->FlowEOF(is_orig);
 	}
 
 void GSSAPI_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
 
 	assert(TCP());
 
@@ -45,12 +47,14 @@ void GSSAPI_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 		}
 	catch ( const binpac::Exception& e )
 		{
-		ProtocolViolation(fmt("Binpac exception: %s", e.c_msg()));
+		ProtocolViolation(util::fmt("Binpac exception: %s", e.c_msg()));
 		}
 	}
 
 void GSSAPI_Analyzer::Undelivered(uint64_t seq, int len, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
 	interp->NewGap(orig, len);
 	}
+
+} // namespace zeek::analyzer::gssapi
