@@ -1,17 +1,17 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
-#include "NVT.h"
+#include "zeek/analyzer/protocol/login/NVT.h"
 
 #include <stdlib.h>
 
-#include "ZeekString.h"
-#include "NetVar.h"
-#include "Event.h"
-#include "Reporter.h"
-#include "analyzer/protocol/tcp/TCP.h"
+#include "zeek/ZeekString.h"
+#include "zeek/NetVar.h"
+#include "zeek/Event.h"
+#include "zeek/Reporter.h"
+#include "zeek/analyzer/protocol/tcp/TCP.h"
 
-#include "events.bif.h"
+#include "analyzer/protocol/login/events.bif.h"
 
 #define IS_3_BYTE_OPTION(c) (c >= 251 && c <= 254)
 
@@ -28,7 +28,7 @@
 
 #define TELNET_IAC 255
 
-using namespace analyzer::login;
+namespace zeek::analyzer::login {
 
 TelnetOption::TelnetOption(NVT_Analyzer* arg_endp, unsigned int arg_code)
 	{
@@ -44,8 +44,8 @@ void TelnetOption::RecvOption(unsigned int type)
 
 	if ( ! peer )
 		{
-		reporter->AnalyzerError(endp,
-		  "option peer missing in TelnetOption::RecvOption");
+		reporter->AnalyzerError(
+			endp, "option peer missing in TelnetOption::RecvOption");
 		return;
 		}
 
@@ -92,8 +92,8 @@ void TelnetOption::RecvOption(unsigned int type)
 		break;
 
 	default:
-		reporter->AnalyzerError(endp,
-		  "bad option type in TelnetOption::RecvOption");
+		reporter->AnalyzerError(
+			endp, "bad option type in TelnetOption::RecvOption");
 		return;
 	}
 	}
@@ -117,6 +117,7 @@ void TelnetOption::BadOption()
 	endp->Event(bad_option);
 	}
 
+namespace detail {
 
 void TelnetTerminalOption::RecvSubOption(u_char* data, int len)
 	{
@@ -175,8 +176,8 @@ void TelnetEncryptOption::RecvSubOption(u_char* data, int len)
 
 		if ( ! peer )
 			{
-			reporter->AnalyzerError(endp,
-			  "option peer missing in TelnetEncryptOption::RecvSubOption");
+			reporter->AnalyzerError(
+				endp, "option peer missing in TelnetEncryptOption::RecvSubOption");
 			return;
 			}
 
@@ -215,8 +216,8 @@ void TelnetAuthenticateOption::RecvSubOption(u_char* data, int len)
 
 		if ( ! peer )
 			{
-			reporter->AnalyzerError(endp,
-			  "option peer missing in TelnetAuthenticateOption::RecvSubOption");
+			reporter->AnalyzerError(
+				endp, "option peer missing in TelnetAuthenticateOption::RecvSubOption");
 			return;
 			}
 
@@ -250,7 +251,7 @@ void TelnetAuthenticateOption::RecvSubOption(u_char* data, int len)
 	case AUTHENTICATION_NAME:
 		{
 		char* auth_name = new char[len];
-		safe_strncpy(auth_name, (char*) data + 1, len);
+		util::safe_strncpy(auth_name, (char*) data + 1, len);
 		endp->SetAuthName(auth_name);
 		}
 		break;
@@ -308,7 +309,7 @@ void TelnetEnvironmentOption::RecvSubOption(u_char* data, int len)
 			break;
 			}
 
-		static_cast<tcp::TCP_ApplicationAnalyzer*>
+		static_cast<analyzer::tcp::TCP_ApplicationAnalyzer*>
 			(endp->Parent())->SetEnv(endp->IsOrig(),
 							var_name, var_val);
 		}
@@ -379,9 +380,10 @@ void TelnetBinaryOption::InconsistentOption(unsigned int /* type */)
 	// in ex/redund-binary-opt.trace.
 	}
 
+} // namespace detail
 
 NVT_Analyzer::NVT_Analyzer(Connection* conn, bool orig)
-	: tcp::ContentLine_Analyzer("NVT", conn, orig), options()
+	: analyzer::tcp::ContentLine_Analyzer("NVT", conn, orig), options()
 	{
 	}
 
@@ -405,23 +407,23 @@ TelnetOption* NVT_Analyzer::FindOption(unsigned int code)
 		{ // Maybe we haven't created this option yet.
 		switch ( code ) {
 		case TELNET_OPTION_BINARY:
-			opt = new TelnetBinaryOption(this);
+			opt = new detail::TelnetBinaryOption(this);
 			break;
 
 		case TELNET_OPTION_TERMINAL:
-			opt = new TelnetTerminalOption(this);
+			opt = new detail::TelnetTerminalOption(this);
 			break;
 
 		case TELNET_OPTION_ENCRYPT:
-			opt = new TelnetEncryptOption(this);
+			opt = new detail::TelnetEncryptOption(this);
 			break;
 
 		case TELNET_OPTION_AUTHENTICATE:
-			opt = new TelnetAuthenticateOption(this);
+			opt = new detail::TelnetAuthenticateOption(this);
 			break;
 
 		case TELNET_OPTION_ENVIRON:
-			opt = new TelnetEnvironmentOption(this);
+			opt = new detail::TelnetEnvironmentOption(this);
 			break;
 		}
 		}
@@ -461,7 +463,7 @@ void NVT_Analyzer::SetTerminal(const u_char* terminal, int len)
 	if ( login_terminal )
 		EnqueueConnEvent(login_terminal,
 			ConnVal(),
-			zeek::make_intrusive<zeek::StringVal>(new zeek::String(terminal, len, false))
+			make_intrusive<StringVal>(new String(terminal, len, false))
 		);
 	}
 
@@ -537,7 +539,7 @@ void NVT_Analyzer::DeliverChunk(int& len, const u_char*& data)
 			else
 				{
 				if ( Conn()->FlagEvent(SINGULAR_LF) )
-					Conn()->Weird("line_terminated_with_single_LF");
+					Weird("line_terminated_with_single_LF");
 				buf[offset++] = c;
 				}
 			break;
@@ -734,3 +736,5 @@ void NVT_Analyzer::BadOptionTermination(unsigned int /* code */)
 	{
 	Event(bad_option_termination);
 	}
+
+} // namespace zeek::analyzer::login
