@@ -1,22 +1,25 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
+#include "zeek/analyzer/protocol/netbios/NetbiosSSN.h"
 
 #include <ctype.h>
 
-#include "NetVar.h"
-#include "NetbiosSSN.h"
-#include "Sessions.h"
-#include "Event.h"
+#include "zeek/ZeekString.h"
+#include "zeek/NetVar.h"
+#include "zeek/Sessions.h"
+#include "zeek/Event.h"
+#include "zeek/RunState.h"
 
-#include "events.bif.h"
+#include "analyzer/protocol/netbios/events.bif.h"
 
-using namespace analyzer::netbios_ssn;
-
-double netbios_ssn_session_timeout = 15.0;
+constexpr double netbios_ssn_session_timeout = 15.0;
 
 #define MAKE_INT16(dest, src) dest = *src; dest <<=8; src++; dest |= *src; src++;
 
+namespace zeek::analyzer::netbios_ssn {
+namespace detail {
+
 NetbiosSSN_RawMsgHdr::NetbiosSSN_RawMsgHdr(const u_char*& data, int& len)
 	{
 	type = *data; ++data, --len;
@@ -46,85 +49,87 @@ NetbiosDGM_RawMsgHdr::NetbiosDGM_RawMsgHdr(const u_char*& data, int& len)
 	MAKE_INT16(offset, data);; len -= 2;
 	}
 
-
-NetbiosSSN_Interpreter::NetbiosSSN_Interpreter(Analyzer* arg_analyzer)
+NetbiosSSN_Interpreter::NetbiosSSN_Interpreter(analyzer::Analyzer* arg_analyzer)
 	{
 	analyzer = arg_analyzer;
 	//smb_session = arg_smb_session;
 	}
 
-int NetbiosSSN_Interpreter::ParseMessage(unsigned int type, unsigned int flags,
-				const u_char* data, int len, int is_query)
+void NetbiosSSN_Interpreter::ParseMessage(unsigned int type, unsigned int flags,
+                                          const u_char* data, int len, bool is_query)
 	{
 	if ( netbios_session_message )
-		{
-		analyzer->ConnectionEventFast(netbios_session_message, {
-			analyzer->BuildConnVal(),
-			val_mgr->GetBool(is_query),
-			val_mgr->GetCount(type),
-			val_mgr->GetCount(len),
-		});
-		}
+		analyzer->EnqueueConnEvent(netbios_session_message,
+			analyzer->ConnVal(),
+			val_mgr->Bool(is_query),
+			val_mgr->Count(type),
+			val_mgr->Count(len)
+		);
 
 	switch ( type ) {
 	case NETBIOS_SSN_MSG:
-		return ParseSessionMsg(data, len, is_query);
+		ParseSessionMsg(data, len, is_query);
+		break;
 
 	case NETBIOS_SSN_REQ:
-		return ParseSessionReq(data, len, is_query);
+		ParseSessionReq(data, len, is_query);
+		break;
 
 	case NETBIOS_SSN_POS_RESP:
-		return ParseSessionPosResp(data, len, is_query);
+		ParseSessionPosResp(data, len, is_query);
+		break;
 
 	case NETBIOS_SSN_NEG_RESP:
-		return ParseSessionNegResp(data, len, is_query);
+		ParseSessionNegResp(data, len, is_query);
+		break;
 
 	case NETBIOS_SSN_RETARG_RESP:
-		return ParseRetArgResp(data, len, is_query);
+		ParseRetArgResp(data, len, is_query);
+		break;
 
 	case NETBIOS_SSN_KEEP_ALIVE:
-		return ParseKeepAlive(data, len, is_query);
+		ParseKeepAlive(data, len, is_query);
+		break;
 
 	case NETBIOS_DGM_DIRECT_UNIQUE:
 	case NETBIOS_DGM_DIRECT_GROUP:
 	case NETBIOS_DGM_BROADCAST:
-		return ParseBroadcast(data, len, is_query);
+		ParseBroadcast(data, len, is_query);
+		break;
 
 	case NETBIOS_DGM_ERROR:
 	case NETBIOS_DGG_QUERY_REQ:
 	case NETBIOS_DGM_POS_RESP:
 	case NETBIOS_DGM_NEG_RESP:
-		return ParseDatagram(data, len, is_query);
+		ParseDatagram(data, len, is_query);
+		break;
 
  	default:
-		analyzer->Weird("unknown_netbios_type", fmt("0x%x", type));
- 		return 1;
+		analyzer->Weird("unknown_netbios_type", util::fmt("0x%x", type));
+		break;
 	}
 	}
 
-int NetbiosSSN_Interpreter::ParseDatagram(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseDatagram(const u_char* data, int len,
+						bool is_query)
 	{
 	//if ( smb_session )
 	//	{
 	//	smb_session->Deliver(is_query, len, data);
-	//	return 0;
 	//	}
-
-	return 0;
  	}
 
-int NetbiosSSN_Interpreter::ParseBroadcast(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseBroadcast(const u_char* data, int len,
+						bool is_query)
  	{
 	// FIND THE NUL-TERMINATED NAME STRINGS HERE!
 	// Not sure what's in them, so we don't keep them currently.
 
-	BroString* srcname = new BroString((char*) data);
+	String* srcname = new String((char*) data);
 	data += srcname->Len()+1;
 	len -= srcname->Len();
 
-	BroString* dstname = new BroString((char*) data);
+	String* dstname = new String((char*) data);
 	data += dstname->Len()+1;
 	len -= dstname->Len();
 
@@ -133,17 +138,15 @@ int NetbiosSSN_Interpreter::ParseBroadcast(const u_char* data, int len,
 
 	//if ( smb_session )
 	//	smb_session->Deliver(is_query, len, data);
-
-	return 0;
 	}
 
-int NetbiosSSN_Interpreter::ParseMessageTCP(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseMessageTCP(const u_char* data, int len,
+						bool is_query)
 	{
 	NetbiosSSN_RawMsgHdr hdr(data, len);
 
 	if ( hdr.length > unsigned(len) )
-		analyzer->Weird("excess_netbios_hdr_len", fmt("(%d > %d)",
+		analyzer->Weird("excess_netbios_hdr_len", util::fmt("(%d > %d)",
 					hdr.length, len));
 
 	else if ( hdr.length < unsigned(len) )
@@ -152,39 +155,38 @@ int NetbiosSSN_Interpreter::ParseMessageTCP(const u_char* data, int len,
 		len = hdr.length;
 		}
 
-	return ParseMessage(hdr.type, hdr.flags, data, len, is_query);
+	ParseMessage(hdr.type, hdr.flags, data, len, is_query);
 	}
 
-int NetbiosSSN_Interpreter::ParseMessageUDP(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseMessageUDP(const u_char* data, int len,
+						bool is_query)
 	{
-
 	NetbiosDGM_RawMsgHdr hdr(data, len);
 
 	if ( unsigned(hdr.length-14) > unsigned(len) )
-		analyzer->Weird("excess_netbios_hdr_len", fmt("(%d > %d)",
+		analyzer->Weird("excess_netbios_hdr_len", util::fmt("(%d > %d)",
 				hdr.length, len));
 
 	else if ( hdr.length < unsigned(len) )
 		{
-		analyzer->Weird("deficit_netbios_hdr_len", fmt("(%d < %d)",
+		analyzer->Weird("deficit_netbios_hdr_len", util::fmt("(%d < %d)",
 				hdr.length, len));
 		len = hdr.length;
 		}
 
-	return ParseMessage(hdr.type, hdr.flags, data, len, is_query);
+	ParseMessage(hdr.type, hdr.flags, data, len, is_query);
 	}
 
 
-int NetbiosSSN_Interpreter::ParseSessionMsg(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseSessionMsg(const u_char* data, int len,
+						bool is_query)
 	{
 	if ( len < 4 || strncmp((const char*) data, "\xffSMB", 4) )
 		{
 		// This should be an event, too.
 		analyzer->Weird("netbios_raw_session_msg");
 		Event(netbios_session_raw_message, data, len, is_query);
-		return 0;
+		return;
 		}
 
 	//if ( smb_session )
@@ -197,14 +199,13 @@ int NetbiosSSN_Interpreter::ParseSessionMsg(const u_char* data, int len,
 		analyzer->Weird("no_smb_session_using_parsesambamsg");
 		data += 4;
 		len -= 4;
-		return ParseSambaMsg(data, len, is_query);
+		ParseSambaMsg(data, len, is_query);
 		}
 	}
 
-int NetbiosSSN_Interpreter::ParseSambaMsg(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseSambaMsg(const u_char* data, int len,
+						bool is_query)
 	{
-	return 0;
 	}
 
 int NetbiosSSN_Interpreter::ConvertName(const u_char* name, int name_len,
@@ -212,7 +213,7 @@ int NetbiosSSN_Interpreter::ConvertName(const u_char* name, int name_len,
 	{
 	// Taken from tcpdump's smbutil.c.
 
-	xname = 0;
+	xname = nullptr;
 
 	if ( name_len < 1 )
 		return 0;
@@ -246,8 +247,8 @@ int NetbiosSSN_Interpreter::ConvertName(const u_char* name, int name_len,
 	return 1;
 	}
 
-int NetbiosSSN_Interpreter::ParseSessionReq(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseSessionReq(const u_char* data, int len,
+						bool is_query)
 	{
 	if ( ! is_query )
 		analyzer->Weird("netbios_server_session_request");
@@ -259,23 +260,19 @@ int NetbiosSSN_Interpreter::ParseSessionReq(const u_char* data, int len,
 		Event(netbios_session_request, xname, xlen);
 
 	delete [] xname;
-
-	return 0;
 	}
 
-int NetbiosSSN_Interpreter::ParseSessionPosResp(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseSessionPosResp(const u_char* data, int len,
+						bool is_query)
 	{
 	if ( is_query )
 		analyzer->Weird("netbios_client_session_reply");
 
 	Event(netbios_session_accepted, data, len);
-
-	return 0;
 	}
 
-int NetbiosSSN_Interpreter::ParseSessionNegResp(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseSessionNegResp(const u_char* data, int len,
+						bool is_query)
 	{
 	if ( is_query )
 		analyzer->Weird("netbios_client_session_reply");
@@ -299,60 +296,51 @@ int NetbiosSSN_Interpreter::ParseSessionNegResp(const u_char* data, int len,
 		printf("Unspecified error 0x%X\n",ecode);
 		break;
 #endif
-
-	return 0;
 	}
 
-int NetbiosSSN_Interpreter::ParseRetArgResp(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseRetArgResp(const u_char* data, int len,
+						bool is_query)
 	{
 	if ( is_query )
 		analyzer->Weird("netbios_client_session_reply");
 
 	Event(netbios_session_ret_arg_resp, data, len);
-
-	return 0;
 	}
 
-int NetbiosSSN_Interpreter::ParseKeepAlive(const u_char* data, int len,
-						int is_query)
+void NetbiosSSN_Interpreter::ParseKeepAlive(const u_char* data, int len,
+						bool is_query)
 	{
 	Event(netbios_session_keepalive, data, len);
-
-	return 0;
 	}
 
 void NetbiosSSN_Interpreter::Event(EventHandlerPtr event, const u_char* data,
-					int len, int is_orig)
+                                   int len, int is_orig)
 	{
 	if ( ! event )
 		return;
 
 	if ( is_orig >= 0 )
-		{
-		analyzer->ConnectionEventFast(event, {
-			analyzer->BuildConnVal(),
-			val_mgr->GetBool(is_orig),
-			new StringVal(new BroString(data, len, 0)),
-		});
-		}
+		analyzer->EnqueueConnEvent(event,
+		                           analyzer->ConnVal(),
+		                           val_mgr->Bool(is_orig),
+		                           make_intrusive<StringVal>(new String(data, len, false)));
 	else
-		analyzer->ConnectionEventFast(event, {
-			analyzer->BuildConnVal(),
-			new StringVal(new BroString(data, len, 0)),
-		});
+		analyzer->EnqueueConnEvent(event,
+		                           analyzer->ConnVal(),
+		                           make_intrusive<StringVal>(new String(data, len, false)));
 	}
 
+} // namespace detail
 
 Contents_NetbiosSSN::Contents_NetbiosSSN(Connection* conn, bool orig,
-					NetbiosSSN_Interpreter* arg_interp)
-: tcp::TCP_SupportAnalyzer("CONTENTS_NETBIOSSSN", conn, orig)
+                                         detail::NetbiosSSN_Interpreter* arg_interp)
+: analyzer::tcp::TCP_SupportAnalyzer("CONTENTS_NETBIOSSSN", conn, orig)
 	{
 	interp = arg_interp;
 	type = flags = msg_size = 0;
-	msg_buf = 0;
+	msg_buf = nullptr;
 	buf_n = buf_len = msg_size = 0;
-	state = NETBIOS_SSN_TYPE;
+	state = detail::NETBIOS_SSN_TYPE;
 	}
 
 Contents_NetbiosSSN::~Contents_NetbiosSSN()
@@ -371,12 +359,18 @@ void Contents_NetbiosSSN::Flush()
 
 void Contents_NetbiosSSN::DeliverStream(int len, const u_char* data, bool orig)
 	{
-	tcp::TCP_SupportAnalyzer::DeliverStream(len, data, orig);
+	while ( len > 0 )
+		ProcessChunk(len, data, orig);
+	}
 
-	if ( state == NETBIOS_SSN_TYPE )
+void Contents_NetbiosSSN::ProcessChunk(int& len, const u_char*& data, bool orig)
+	{
+	analyzer::tcp::TCP_SupportAnalyzer::DeliverStream(len, data, orig);
+
+	if ( state == detail::NETBIOS_SSN_TYPE )
 		{
 		type = *data;
-		state = NETBIOS_SSN_FLAGS;
+		state = detail::NETBIOS_SSN_FLAGS;
 
 		++data;
 		--len;
@@ -385,10 +379,10 @@ void Contents_NetbiosSSN::DeliverStream(int len, const u_char* data, bool orig)
 			return;
 		}
 
-	if ( state == NETBIOS_SSN_FLAGS )
+	if ( state == detail::NETBIOS_SSN_FLAGS )
 		{
 		flags = *data;
-		state = NETBIOS_SSN_LEN_HI;
+		state = detail::NETBIOS_SSN_LEN_HI;
 
 		++data;
 		--len;
@@ -397,10 +391,10 @@ void Contents_NetbiosSSN::DeliverStream(int len, const u_char* data, bool orig)
 			return;
 		}
 
-	if ( state == NETBIOS_SSN_LEN_HI )
+	if ( state == detail::NETBIOS_SSN_LEN_HI )
 		{
 		msg_size = (*data) << 8;
-		state = NETBIOS_SSN_LEN_LO;
+		state = detail::NETBIOS_SSN_LEN_LO;
 
 		++data;
 		--len;
@@ -409,10 +403,10 @@ void Contents_NetbiosSSN::DeliverStream(int len, const u_char* data, bool orig)
 			return;
 		}
 
-	if ( state == NETBIOS_SSN_LEN_LO )
+	if ( state == detail::NETBIOS_SSN_LEN_LO )
 		{
 		msg_size += *data;
-		state = NETBIOS_SSN_BUF;
+		state = detail::NETBIOS_SSN_BUF;
 
 		buf_n = 0;
 
@@ -439,33 +433,32 @@ void Contents_NetbiosSSN::DeliverStream(int len, const u_char* data, bool orig)
 			return;
 		}
 
-	if ( state != NETBIOS_SSN_BUF )
+	if ( state != detail::NETBIOS_SSN_BUF )
 		Conn()->Internal("state inconsistency in Contents_NetbiosSSN::Deliver");
 
 	int n;
 	for ( n = 0; buf_n < msg_size && n < len; ++n )
 		msg_buf[buf_n++] = data[n];
 
+	data += n;
+	len -= n;
+
 	if ( buf_n < msg_size )
 		// Haven't filled up the message buffer yet, no more to do.
 		return;
 
-	(void) interp->ParseMessage(type, flags, msg_buf, msg_size, IsOrig());
+	interp->ParseMessage(type, flags, msg_buf, msg_size, IsOrig());
 	buf_n = 0;
 
-	state = NETBIOS_SSN_TYPE;
-
-	if ( n < len )
-		// More data to munch on.
-		DeliverStream(len - n, data + n, orig);
+	state = detail::NETBIOS_SSN_TYPE;
 	}
 
 NetbiosSSN_Analyzer::NetbiosSSN_Analyzer(Connection* conn)
-: tcp::TCP_ApplicationAnalyzer("NETBIOSSSN", conn)
+: analyzer::tcp::TCP_ApplicationAnalyzer("NETBIOSSSN", conn)
 	{
 	//smb_session = new SMB_Session(this);
-	interp = new NetbiosSSN_Interpreter(this);
-	orig_netbios = resp_netbios = 0;
+	interp = new detail::NetbiosSSN_Interpreter(this);
+	orig_netbios = resp_netbios = nullptr;
 	did_session_done = 0;
 
 	if ( Conn()->ConnTransport() == TRANSPORT_TCP )
@@ -478,8 +471,8 @@ NetbiosSSN_Analyzer::NetbiosSSN_Analyzer(Connection* conn)
 	else
 		{
 		ADD_ANALYZER_TIMER(&NetbiosSSN_Analyzer::ExpireTimer,
-				network_time + netbios_ssn_session_timeout, 1,
-				TIMER_NB_EXPIRE);
+		                   run_state::network_time + netbios_ssn_session_timeout, true,
+		                   zeek::detail::TIMER_NB_EXPIRE);
 		}
 	}
 
@@ -491,7 +484,7 @@ NetbiosSSN_Analyzer::~NetbiosSSN_Analyzer()
 
 void NetbiosSSN_Analyzer::Done()
 	{
-	tcp::TCP_ApplicationAnalyzer::Done();
+	analyzer::tcp::TCP_ApplicationAnalyzer::Done();
 	interp->Timeout();
 
 	if ( Conn()->ConnTransport() == TRANSPORT_UDP && ! did_session_done )
@@ -502,15 +495,15 @@ void NetbiosSSN_Analyzer::Done()
 
 void NetbiosSSN_Analyzer::EndpointEOF(bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::EndpointEOF(orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::EndpointEOF(orig);
 
 	(orig ? orig_netbios : resp_netbios)->Flush();
 	}
 
-void NetbiosSSN_Analyzer::ConnectionClosed(tcp::TCP_Endpoint* endpoint,
-				tcp::TCP_Endpoint* peer, int gen_event)
+void NetbiosSSN_Analyzer::ConnectionClosed(analyzer::tcp::TCP_Endpoint* endpoint,
+                                           analyzer::tcp::TCP_Endpoint* peer, bool gen_event)
 	{
-	tcp::TCP_ApplicationAnalyzer::ConnectionClosed(endpoint, peer, gen_event);
+	analyzer::tcp::TCP_ApplicationAnalyzer::ConnectionClosed(endpoint, peer, gen_event);
 
 	// Question: Why do we flush *both* endpoints upon connection close?
 	// orig_netbios->Flush();
@@ -518,14 +511,14 @@ void NetbiosSSN_Analyzer::ConnectionClosed(tcp::TCP_Endpoint* endpoint,
 	}
 
 void NetbiosSSN_Analyzer::DeliverPacket(int len, const u_char* data, bool orig,
-					uint64 seq, const IP_Hdr* ip, int caplen)
+					uint64_t seq, const IP_Hdr* ip, int caplen)
 	{
-	tcp::TCP_ApplicationAnalyzer::DeliverPacket(len, data, orig, seq, ip, caplen);
+	analyzer::tcp::TCP_ApplicationAnalyzer::DeliverPacket(len, data, orig, seq, ip, caplen);
 
 	if ( orig )
-		interp->ParseMessageUDP(data, len, 1);
+		interp->ParseMessageUDP(data, len, true);
 	else
-		interp->ParseMessageUDP(data, len, 0);
+		interp->ParseMessageUDP(data, len, false);
 	}
 
 void NetbiosSSN_Analyzer::ExpireTimer(double t)
@@ -533,8 +526,8 @@ void NetbiosSSN_Analyzer::ExpireTimer(double t)
 	// The - 1.0 in the following is to allow 1 second for the
 	// common case of a single request followed by a single reply,
 	// so we don't needlessly set the timer twice in that case.
-	if ( terminating ||
-	     network_time - Conn()->LastTime() >=
+	if ( run_state::terminating ||
+	     run_state::network_time - Conn()->LastTime() >=
 		     netbios_ssn_session_timeout - 1.0 )
 		{
 		Event(connection_timeout);
@@ -542,6 +535,8 @@ void NetbiosSSN_Analyzer::ExpireTimer(double t)
 		}
 	else
 		ADD_ANALYZER_TIMER(&NetbiosSSN_Analyzer::ExpireTimer,
-				t + netbios_ssn_session_timeout,
-				1, TIMER_NB_EXPIRE);
+		                   t + netbios_ssn_session_timeout,
+		                   true, zeek::detail::TIMER_NB_EXPIRE);
 	}
+
+} // namespace zeek::analyzer::netbios_ssn
