@@ -2,19 +2,19 @@
 // Robin Sommer.
 
 #include "zeek-config.h"
-#include "POP3.h"
+#include "zeek/analyzer/protocol/pop3/POP3.h"
 
 #include <vector>
 #include <string>
 #include <ctype.h>
 
-#include "Base64.h"
-#include "Reporter.h"
-#include "analyzer/Manager.h"
+#include "zeek/Base64.h"
+#include "zeek/Reporter.h"
+#include "zeek/analyzer/Manager.h"
 
-#include "events.bif.h"
+#include "analyzer/protocol/pop3/events.bif.h"
 
-using namespace analyzer::pop3;
+namespace zeek::analyzer::pop3 {
 
 #undef POP3_CMD_DEF
 #define POP3_CMD_DEF(cmd)	#cmd,
@@ -25,14 +25,13 @@ static const char* pop3_cmd_word[] = {
 
 #define POP3_CMD_WORD(code) ((code >= 0) ? pop3_cmd_word[code] : "(UNKNOWN)")
 
-
 POP3_Analyzer::POP3_Analyzer(Connection* conn)
-: tcp::TCP_ApplicationAnalyzer("POP3", conn)
+: analyzer::tcp::TCP_ApplicationAnalyzer("POP3", conn)
 	{
-	masterState = POP3_START;
-	subState = POP3_WOK;
-	state = START;
-	lastState = START;
+	masterState = detail::POP3_START;
+	subState = detail::POP3_WOK;
+	state = detail::START;
+	lastState = detail::START;
 
 	guessing = false;
 	waitingForAuthentication = false;
@@ -43,12 +42,12 @@ POP3_Analyzer::POP3_Analyzer(Connection* conn)
 	lastRequiredCommand = 0;
 	authLines = 0;
 
-	mail = 0;
+	mail = nullptr;
 
-	cl_orig = new tcp::ContentLine_Analyzer(conn, true);
+	cl_orig = new analyzer::tcp::ContentLine_Analyzer(conn, true);
 	AddSupportAnalyzer(cl_orig);
 
-	cl_resp = new tcp::ContentLine_Analyzer(conn, false);
+	cl_resp = new analyzer::tcp::ContentLine_Analyzer(conn, false);
 	AddSupportAnalyzer(cl_resp);
 	}
 
@@ -58,7 +57,7 @@ POP3_Analyzer::~POP3_Analyzer()
 
 void POP3_Analyzer::Done()
 	{
-	tcp::TCP_ApplicationAnalyzer::Done();
+	analyzer::tcp::TCP_ApplicationAnalyzer::Done();
 
 	if ( mail )
 		EndData();
@@ -67,7 +66,7 @@ void POP3_Analyzer::Done()
 
 void POP3_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
 
 	if ( tls )
 		{
@@ -78,7 +77,7 @@ void POP3_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 	if ( (TCP() && TCP()->IsPartial()) )
 		return;
 
-	BroString terminated_string(data, len, 1);
+	String terminated_string(data, len, true);
 
 	if ( orig )
 		ProcessRequest(len, (char*) terminated_string.Bytes());
@@ -86,13 +85,13 @@ void POP3_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 		ProcessReply(len, (char*) terminated_string.Bytes());
 	}
 
-static string trim_whitespace(const char* in)
+static std::string trim_whitespace(const char* in)
 	{
 	int n = strlen(in);
 	char* out = new char[n + 1];
 	char* out_p = out;
 
-	in = skip_whitespace(in);
+	in = util::skip_whitespace(in);
 
 	while ( *in )
 		{
@@ -121,7 +120,7 @@ static string trim_whitespace(const char* in)
 
 	*out_p = 0;
 
-	string rval(out);
+	std::string rval(out);
 	delete [] out;
 	return rval;
 	}
@@ -135,8 +134,8 @@ void POP3_Analyzer::ProcessRequest(int length, const char* line)
 		{
 		++authLines;
 
-		BroString encoded(line);
-		BroString* decoded = decode_base64(&encoded, 0, Conn());
+		String encoded(line);
+		String* decoded = zeek::detail::decode_base64(&encoded, nullptr, Conn());
 
 		if ( ! decoded )
 			{
@@ -145,7 +144,7 @@ void POP3_Analyzer::ProcessRequest(int length, const char* line)
 			}
 
 		switch ( state ) {
-		case AUTH_LOGIN:
+		case detail::AUTH_LOGIN:
 			// Format: Line 1 - User
 			//         Line 2 - Password
 			if ( authLines == 1 )
@@ -156,7 +155,7 @@ void POP3_Analyzer::ProcessRequest(int length, const char* line)
 
 			break;
 
-		case AUTH_PLAIN:
+		case detail::AUTH_PLAIN:
 			{
 			// Format: "authorization identity<NUL>authentication
 			//		identity<NUL>password"
@@ -195,7 +194,7 @@ void POP3_Analyzer::ProcessRequest(int length, const char* line)
 			break;
 			}
 
-		case AUTH_CRAM_MD5:
+		case detail::AUTH_CRAM_MD5:
 			{ // Format: "user<space>password-hash"
 			const char* s;
 			const char* str = (char*) decoded->CheckString();
@@ -209,12 +208,12 @@ void POP3_Analyzer::ProcessRequest(int length, const char* line)
 			break;
 			}
 
-		case AUTH:
+		case detail::AUTH:
 			break;
 
 		default:
-			reporter->AnalyzerError(this,
-			  "unexpected POP3 authorization state");
+			reporter->AnalyzerError(
+				this, "unexpected POP3 authorization state");
 			delete decoded;
 			return;
 		}
@@ -227,7 +226,7 @@ void POP3_Analyzer::ProcessRequest(int length, const char* line)
 		// Some clients pipeline their commands (i.e., keep sending
 		// without waiting for a server's responses). Therefore we
 		// keep a list of pending commands.
-		cmds.push_back(string(line));
+		cmds.push_back(std::string(line));
 
 		if ( cmds.size() == 1 )
 			// Not waiting for another server response,
@@ -237,7 +236,7 @@ void POP3_Analyzer::ProcessRequest(int length, const char* line)
 
 	}
 
-static string commands[] = {
+static std::string commands[] = {
 	"OK", "ERR", "USER", "PASS", "APOP", "AUTH",
 	"STAT", "LIST", "RETR", "DELE", "RSET", "NOOP", "LAST", "QUIT",
 	"TOP", "CAPA", "UIDL", "STLS", "XSENDER",
@@ -246,7 +245,7 @@ static string commands[] = {
 void POP3_Analyzer::NotAllowed(const char* cmd, const char* state)
 	{
 	POP3Event(pop3_unexpected, true, cmd,
-		fmt("not allowed in other state than '%s'", state));
+		util::fmt("not allowed in other state than '%s'", state));
 	}
 
 void POP3_Analyzer::ProcessClientCmd()
@@ -254,8 +253,8 @@ void POP3_Analyzer::ProcessClientCmd()
 	if ( ! cmds.size() )
 		return;
 
-	string str = trim_whitespace(cmds.front().c_str());
-	vector<string> tokens = TokenizeLine(str, ' ');
+	std::string str = trim_whitespace(cmds.front().c_str());
+	std::vector<std::string> tokens = TokenizeLine(str, ' ');
 
 	int cmd_code = -1;
 	const char* cmd = "";
@@ -268,8 +267,8 @@ void POP3_Analyzer::ProcessClientCmd()
 		if ( ! waitingForAuthentication )
 			{
 			Weird("pop3_client_command_unknown");
-			if ( subState == POP3_WOK )
-				subState = POP3_OK;
+			if ( subState == detail::POP3_WOK )
+				subState = detail::POP3_OK;
 			}
 		return;
 		}
@@ -279,31 +278,31 @@ void POP3_Analyzer::ProcessClientCmd()
 	const char* message = tokens.size() > 1 ? tokens[1].c_str() : "";
 
 	switch ( cmd_code ) {
-	case POP3_CMD_ERR:
-	case POP3_CMD_OK:
+	case detail::POP3_CMD_ERR:
+	case detail::POP3_CMD_OK:
 		Weird("pop3_client_sending_server_commands");
 		break;
 
-	case POP3_CMD_USER:
-		if ( masterState == POP3_AUTHORIZATION )
+	case detail::POP3_CMD_USER:
+		if ( masterState == detail::POP3_AUTHORIZATION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			state = USER;
-			subState = POP3_WOK;
+			state = detail::USER;
+			subState = detail::POP3_WOK;
 			user = message;
 			}
 		else
 			NotAllowed(cmd, "authorization");
 		break;
 
-	case POP3_CMD_PASS:
-		if ( masterState == POP3_AUTHORIZATION )
+	case detail::POP3_CMD_PASS:
+		if ( masterState == detail::POP3_AUTHORIZATION )
 			{
-			if ( state == USER )
+			if ( state == detail::USER )
 				{
 				POP3Event(pop3_request, true, cmd, message);
-				state = PASS;
-				subState = POP3_WOK;
+				state = detail::PASS;
+				subState = detail::POP3_WOK;
 				password = message;
 				}
 			else
@@ -314,14 +313,14 @@ void POP3_Analyzer::ProcessClientCmd()
 			NotAllowed(cmd, "authorization");
 		break;
 
-	case POP3_CMD_APOP:
-		if ( masterState == POP3_AUTHORIZATION )
+	case detail::POP3_CMD_APOP:
+		if ( masterState == detail::POP3_AUTHORIZATION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			state = APOP;
-			subState = POP3_WOK;
+			state = detail::APOP;
+			subState = detail::POP3_WOK;
 
-			char* arg1 = copy_string(message);
+			char* arg1 = util::copy_string(message);
 			char* e;
 			for ( e = arg1; *e && *e != ' ' && *e != '\t'; ++e )
 				;
@@ -333,32 +332,32 @@ void POP3_Analyzer::ProcessClientCmd()
 			NotAllowed(cmd, "authorization");
 		break;
 
-	case POP3_CMD_AUTH:
-		if ( masterState == POP3_AUTHORIZATION )
+	case detail::POP3_CMD_AUTH:
+		if ( masterState == detail::POP3_AUTHORIZATION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
 			if ( ! *message )
 				{
 				requestForMultiLine = true;
-				state = AUTH;
-				subState = POP3_WOK;
+				state = detail::AUTH;
+				subState = detail::POP3_WOK;
 				}
 			else
 				{
 				if ( strstr(message, "LOGIN") )
-					state = AUTH_LOGIN;
+					state = detail::AUTH_LOGIN;
 				else if ( strstr(message, "PLAIN") )
-					state = AUTH_PLAIN;
+					state = detail::AUTH_PLAIN;
 				else if ( strstr(message, "CRAM-MD5") )
-					state = AUTH_CRAM_MD5;
+					state = detail::AUTH_CRAM_MD5;
 				else
 					{
-					state = AUTH;
+					state = detail::AUTH;
 					POP3Event(pop3_unexpected, true, cmd,
-						fmt("unknown AUTH method %s", message));
+						util::fmt("unknown AUTH method %s", message));
 					}
 
-				subState = POP3_WOK;
+				subState = detail::POP3_WOK;
 				waitingForAuthentication = true;
 				authLines = 0;
 				}
@@ -368,31 +367,31 @@ void POP3_Analyzer::ProcessClientCmd()
 				"pass must follow the command 'USER'");
 		break;
 
-	case POP3_CMD_STAT:
-		if ( masterState == POP3_TRANSACTION )
+	case detail::POP3_CMD_STAT:
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = STAT;
+			subState = detail::POP3_WOK;
+			state = detail::STAT;
 			}
 		else
 			NotAllowed(cmd, "transaction");
 		break;
 
-	case POP3_CMD_LIST:
-		if ( masterState == POP3_TRANSACTION )
+	case detail::POP3_CMD_LIST:
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
 			if ( ! *message )
 				{
 				requestForMultiLine = true;
-				state = LIST;
-				subState = POP3_WOK;
+				state = detail::LIST;
+				subState = detail::POP3_WOK;
 				}
 			else
 				{
-				state = LIST;
-				subState = POP3_WOK;
+				state = detail::LIST;
+				subState = detail::POP3_WOK;
 				}
 			}
 		else
@@ -401,148 +400,148 @@ void POP3_Analyzer::ProcessClientCmd()
 				requestForMultiLine = true;
 
 			guessing = true;
-			lastState = LIST;
+			lastState = detail::LIST;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_RETR:
+	case detail::POP3_CMD_RETR:
 		requestForMultiLine = true;
-		if ( masterState == POP3_TRANSACTION )
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = RETR;
+			subState = detail::POP3_WOK;
+			state = detail::RETR;
 			}
 		else
 			{
 			guessing = true;
-			lastState = RETR;
+			lastState = detail::RETR;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_DELE:
-		if ( masterState == POP3_TRANSACTION )
+	case detail::POP3_CMD_DELE:
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = DELE;
+			subState = detail::POP3_WOK;
+			state = detail::DELE;
 			}
 		else
 			{
 			guessing = true;
-			lastState = DELE;
+			lastState = detail::DELE;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_RSET:
-		if ( masterState == POP3_TRANSACTION )
+	case detail::POP3_CMD_RSET:
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = RSET;
+			subState = detail::POP3_WOK;
+			state = detail::RSET;
 			}
 		else
 			{
 			guessing = true;
-			lastState = RSET;
+			lastState = detail::RSET;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_NOOP:
-		if ( masterState == POP3_TRANSACTION )
+	case detail::POP3_CMD_NOOP:
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = NOOP;
+			subState = detail::POP3_WOK;
+			state = detail::NOOP;
 			}
 		else
 			{
 			guessing = true;
-			lastState = NOOP;
+			lastState = detail::NOOP;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_LAST:
-		if ( masterState == POP3_TRANSACTION )
+	case detail::POP3_CMD_LAST:
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = LAST;
+			subState = detail::POP3_WOK;
+			state = detail::LAST;
 			}
 		else
 			{
 			guessing = true;
-			lastState = LAST;
+			lastState = detail::LAST;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_QUIT:
-		if ( masterState == POP3_AUTHORIZATION ||
-		     masterState == POP3_TRANSACTION ||
-		     masterState == POP3_START )
+	case detail::POP3_CMD_QUIT:
+		if ( masterState == detail::POP3_AUTHORIZATION ||
+		     masterState == detail::POP3_TRANSACTION ||
+		     masterState == detail::POP3_START )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = QUIT;
+			subState = detail::POP3_WOK;
+			state = detail::QUIT;
 			}
 		else
 			{
 			guessing = true;
-			lastState = LAST;
+			lastState = detail::LAST;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_TOP:
+	case detail::POP3_CMD_TOP:
 		requestForMultiLine = true;
 
-		if ( masterState == POP3_TRANSACTION )
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = TOP;
+			subState = detail::POP3_WOK;
+			state = detail::TOP;
 			}
 		else
 			{
 			guessing = true;
-			lastState = TOP;
+			lastState = detail::TOP;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_CAPA:
+	case detail::POP3_CMD_CAPA:
 		POP3Event(pop3_request, true, cmd, message);
-		subState = POP3_WOK;
-		state = CAPA;
+		subState = detail::POP3_WOK;
+		state = detail::CAPA;
 		requestForMultiLine = true;
 		break;
 
-	case POP3_CMD_STLS:
+	case detail::POP3_CMD_STLS:
 		POP3Event(pop3_request, true, cmd, message);
-		subState = POP3_WOK;
-		state = STLS;
+		subState = detail::POP3_WOK;
+		state = detail::STLS;
 		break;
 
-	case POP3_CMD_UIDL:
-		if ( masterState == POP3_TRANSACTION )
+	case detail::POP3_CMD_UIDL:
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
 			if ( ! *message )
 				{
 				requestForMultiLine = true;
-				state = UIDL;
-				subState = POP3_WOK;
+				state = detail::UIDL;
+				subState = detail::POP3_WOK;
 				}
 			else
 				{
-				state = UIDL;
-				subState = POP3_WOK;
+				state = detail::UIDL;
+				subState = detail::POP3_WOK;
 				}
 			}
 		else
@@ -551,22 +550,22 @@ void POP3_Analyzer::ProcessClientCmd()
 				requestForMultiLine = true;
 
 			guessing = true;
-			lastState = UIDL;
+			lastState = detail::UIDL;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
 
-	case POP3_CMD_XSENDER:
-		if ( masterState == POP3_TRANSACTION )
+	case detail::POP3_CMD_XSENDER:
+		if ( masterState == detail::POP3_TRANSACTION )
 			{
 			POP3Event(pop3_request, true, cmd, message);
-			subState = POP3_WOK;
-			state = LAST;
+			subState = detail::POP3_WOK;
+			state = detail::LAST;
 			}
 		else
 			{
 			guessing = true;
-			lastState = XSENDER;
+			lastState = detail::XSENDER;
 			NotAllowed(cmd, "transaction");
 			}
 		break;
@@ -589,7 +588,7 @@ void POP3_Analyzer::FinishClientCmd()
 void POP3_Analyzer::ProcessReply(int length, const char* line)
 	{
 	const char* end_of_line = line + length;
-	string str = trim_whitespace(line);
+	std::string str = trim_whitespace(line);
 
 	if ( multiLine == true )
 		{
@@ -610,7 +609,7 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 			}
 		else
 			{
-			if ( state == RETR || state == TOP )
+			if ( state == detail::RETR || state == detail::TOP )
 				{
 				int data_len = end_of_line - line;
 				ProcessData(data_len, line);
@@ -627,7 +626,7 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 	int cmd_code = -1;
 	const char* cmd = "";
 
-	vector<string> tokens = TokenizeLine(str, ' ');
+	std::vector<std::string> tokens = TokenizeLine(str, ' ');
 	if ( tokens.size() > 0 )
 		cmd_code = ParseCmd(tokens[0]);
 
@@ -635,15 +634,15 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 		{
 		if ( ! waitingForAuthentication )
 			{
-			ProtocolViolation(fmt("unknown server command (%s)",
-						(tokens.size() > 0 ?
-							tokens[0].c_str() :
-							"???")),
-						line, length);
+			ProtocolViolation(util::fmt("unknown server command (%s)",
+			                                  (tokens.size() > 0 ?
+			                                   tokens[0].c_str() :
+			                                   "???")),
+			                  line, length);
 
 			Weird("pop3_server_command_unknown");
-			if ( subState == POP3_WOK )
-				subState = POP3_OK;
+			if ( subState == detail::POP3_WOK )
+				subState = detail::POP3_OK;
 			}
 		return;
 		}
@@ -653,13 +652,13 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 	const char* message = tokens.size() > 1 ? tokens[1].c_str() : "";
 
 	switch ( cmd_code ) {
-	case POP3_CMD_OK:
-		if ( subState == POP3_WOK )
-			subState = POP3_OK;
+	case detail::POP3_CMD_OK:
+		if ( subState == detail::POP3_WOK )
+			subState = detail::POP3_OK;
 
 		if ( guessing )
 			{
-			masterState = POP3_TRANSACTION;
+			masterState = detail::POP3_TRANSACTION;
 			guessing = false;
 			state = lastState;
 			POP3Event(pop3_unexpected, false, cmd,
@@ -667,43 +666,43 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 			}
 
 		switch ( state ) {
-		case START:
-			masterState = POP3_AUTHORIZATION;
+		case detail::START:
+			masterState = detail::POP3_AUTHORIZATION;
 			break;
 
-		case USER:
-			state = USER;
-			masterState = POP3_AUTHORIZATION;
+		case detail::USER:
+			state = detail::USER;
+			masterState = detail::POP3_AUTHORIZATION;
 			ProtocolConfirmation();
 			break;
 
-		case PASS:
-		case APOP:
-		case NOOP:
-		case LAST:
-		case STAT:
-		case RSET:
-		case DELE:
-		case XSENDER:
-			if ( masterState == POP3_AUTHORIZATION )
+		case detail::PASS:
+		case detail::APOP:
+		case detail::NOOP:
+		case detail::LAST:
+		case detail::STAT:
+		case detail::RSET:
+		case detail::DELE:
+		case detail::XSENDER:
+			if ( masterState == detail::POP3_AUTHORIZATION )
 				AuthSuccessfull();
-			masterState = POP3_TRANSACTION;
+			masterState = detail::POP3_TRANSACTION;
 			break;
 
-		case AUTH:
-		case AUTH_PLAIN:
-		case AUTH_CRAM_MD5:
-		case AUTH_LOGIN:
+		case detail::AUTH:
+		case detail::AUTH_PLAIN:
+		case detail::AUTH_CRAM_MD5:
+		case detail::AUTH_LOGIN:
 			if ( requestForMultiLine == true )
 				multiLine = true;
 			if ( waitingForAuthentication )
-				masterState = POP3_TRANSACTION;
+				masterState = detail::POP3_TRANSACTION;
 			waitingForAuthentication = false;
 			AuthSuccessfull();
 			break;
 
-		case TOP:
-		case RETR:
+		case detail::TOP:
+		case detail::RETR:
 			{
 			int data_len = end_of_line - line;
 			if ( ! mail )
@@ -715,29 +714,29 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 			break;
 			}
 
-		case CAPA:
+		case detail::CAPA:
 			ProtocolConfirmation();
 			// Fall-through.
 
-		case UIDL:
-		case LIST:
+		case detail::UIDL:
+		case detail::LIST:
 			if (requestForMultiLine == true)
 				multiLine = true;
 			break;
 
-		case STLS:
+		case detail::STLS:
 			ProtocolConfirmation();
 			tls = true;
 			StartTLS();
 			return;
 
-		case QUIT:
-			if ( masterState == POP3_AUTHORIZATION ||
-			     masterState == POP3_START )
-				masterState = POP3_FINISHED;
+		case detail::QUIT:
+			if ( masterState == detail::POP3_AUTHORIZATION ||
+			     masterState == detail::POP3_START )
+				masterState = detail::POP3_FINISHED;
 
-			else if ( masterState == POP3_TRANSACTION )
-				masterState = POP3_UPDATE;
+			else if ( masterState == detail::POP3_TRANSACTION )
+				masterState = detail::POP3_UPDATE;
 
 			break;
 		}
@@ -749,9 +748,9 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 			FinishClientCmd();
 		break;
 
-	case POP3_CMD_ERR:
-		if ( subState == POP3_WOK )
-			subState = POP3_OK;
+	case detail::POP3_CMD_ERR:
+		if ( subState == detail::POP3_WOK )
+			subState = detail::POP3_OK;
 
 		multiLine = false;
 		requestForMultiLine = false;
@@ -759,18 +758,18 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 		waitingForAuthentication = false;
 
 		switch ( state ) {
-		case START:
+		case detail::START:
 			break;
 
-		case USER:
-		case PASS:
-		case APOP:
-		case AUTH:
-		case AUTH_LOGIN:
-		case AUTH_PLAIN:
-		case AUTH_CRAM_MD5:
-			masterState = POP3_AUTHORIZATION;
-			state = START;
+		case detail::USER:
+		case detail::PASS:
+		case detail::APOP:
+		case detail::AUTH:
+		case detail::AUTH_LOGIN:
+		case detail::AUTH_PLAIN:
+		case detail::AUTH_CRAM_MD5:
+			masterState = detail::POP3_AUTHORIZATION;
+			state = detail::START;
 			waitingForAuthentication = false;
 
 			if ( user.size() )
@@ -778,27 +777,27 @@ void POP3_Analyzer::ProcessReply(int length, const char* line)
 					user.c_str(), password.c_str());
 			break;
 
-		case NOOP:
-		case LAST:
-		case STAT:
-		case RSET:
-		case DELE:
-		case LIST:
-		case RETR:
-		case UIDL:
-		case TOP:
-		case XSENDER:
-			masterState = POP3_TRANSACTION;
+		case detail::NOOP:
+		case detail::LAST:
+		case detail::STAT:
+		case detail::RSET:
+		case detail::DELE:
+		case detail::LIST:
+		case detail::RETR:
+		case detail::UIDL:
+		case detail::TOP:
+		case detail::XSENDER:
+			masterState = detail::POP3_TRANSACTION;
 			break;
 
-		case CAPA:
+		case detail::CAPA:
 			break;
 
-		case QUIT:
-			if ( masterState == POP3_AUTHORIZATION ||
-			     masterState == POP3_TRANSACTION ||
-			     masterState == POP3_START )
-				masterState = POP3_FINISHED;
+		case detail::QUIT:
+			if ( masterState == detail::POP3_AUTHORIZATION ||
+			     masterState == detail::POP3_TRANSACTION ||
+			     masterState == detail::POP3_START )
+				masterState = detail::POP3_FINISHED;
 			break;
 		}
 
@@ -826,7 +825,7 @@ void POP3_Analyzer::StartTLS()
 		AddChildAnalyzer(ssl);
 
 	if ( pop3_starttls )
-		ConnectionEventFast(pop3_starttls, {BuildConnVal()});
+		EnqueueConnEvent(pop3_starttls, ConnVal());
 	}
 
 void POP3_Analyzer::AuthSuccessfull()
@@ -839,7 +838,7 @@ void POP3_Analyzer::AuthSuccessfull()
 void POP3_Analyzer::BeginData(bool orig)
 	{
 	delete mail;
-	mail = new mime::MIME_Mail(this, orig);
+	mail = new analyzer::mime::MIME_Mail(this, orig);
 	}
 
 void POP3_Analyzer::EndData()
@@ -850,27 +849,27 @@ void POP3_Analyzer::EndData()
 		{
 		mail->Done();
 		delete mail;
-		mail = 0;
+		mail = nullptr;
 		}
 	}
 
 void POP3_Analyzer::ProcessData(int length, const char* line)
 	{
-	mail->Deliver(length, line, 1);
+	mail->Deliver(length, line, true);
 	}
 
-int POP3_Analyzer::ParseCmd(string cmd)
+int POP3_Analyzer::ParseCmd(std::string cmd)
 	{
 	if ( cmd.size() == 0 )
 		return -1;
 
-	for ( int code = POP3_CMD_OK; code < POP3_CMD_END; ++code )
+	for ( int code = detail::POP3_CMD_OK; code < detail::POP3_CMD_END; ++code )
 		{
 		char c = cmd.c_str()[0];
 		if ( c == '+' || c == '-' )
 			cmd = cmd.substr(1);
 
-		for ( unsigned int i = 0; i < cmd.size(); ++i )
+		for ( size_t i = 0; i < cmd.size(); ++i )
 			cmd[i] = toupper(cmd[i]);
 
 		if ( ! cmd.compare(pop3_cmd_word[code]) )
@@ -880,18 +879,18 @@ int POP3_Analyzer::ParseCmd(string cmd)
 	return -1;
 	}
 
-vector<string> POP3_Analyzer::TokenizeLine(const string input, const char split)
+std::vector<std::string> POP3_Analyzer::TokenizeLine(const std::string& input, char split)
 	{
-	vector<string> tokens;
+	std::vector<std::string> tokens;
 
 	if ( input.size() < 1 )
 		return tokens;
 
 	int start = 0;
 	unsigned int splitPos = 0;
-	string token = "";
+	std::string token = "";
 
-	if ( input.find(split, 0) == string::npos )
+	if ( input.find(split, 0) == std::string::npos )
 		{
 		tokens.push_back(input);
 		return tokens;
@@ -911,19 +910,23 @@ vector<string> POP3_Analyzer::TokenizeLine(const string input, const char split)
 	}
 
 void POP3_Analyzer::POP3Event(EventHandlerPtr event, bool is_orig,
-				const char* arg1, const char* arg2)
+                              const char* arg1, const char* arg2)
 	{
 	if ( ! event )
 		return;
 
-	val_list vl(2 + (bool)arg1 + (bool)arg2);
+	Args vl;
+	vl.reserve(2 + (bool)arg1 + (bool)arg2);
+
+	vl.emplace_back(ConnVal());
+	vl.emplace_back(val_mgr->Bool(is_orig));
 
-	vl.push_back(BuildConnVal());
-	vl.push_back(val_mgr->GetBool(is_orig));
 	if ( arg1 )
-		vl.push_back(new StringVal(arg1));
+		vl.emplace_back(make_intrusive<StringVal>(arg1));
 	if ( arg2 )
-		vl.push_back(new StringVal(arg2));
+		vl.emplace_back(make_intrusive<StringVal>(arg2));
 
-	ConnectionEventFast(event, std::move(vl));
+	EnqueueConnEvent(event, std::move(vl));
 	}
+
+} // namespace zeek::analyzer::pop3
