@@ -1,9 +1,11 @@
-#include "RDPEUDP.h"
-#include "Reporter.h"
-#include "events.bif.h"
-#include "rdpeudp_pac.h"
+#include "zeek/analyzer/protocol/rdp/RDPEUDP.h"
 
-using namespace analyzer::rdpeudp;
+#include "zeek/Reporter.h"
+
+#include "analyzer/protocol/rdp/events.bif.h"
+#include "analyzer/protocol/rdp/rdpeudp_pac.h"
+
+namespace zeek::analyzer::rdpeudp {
 
 RDP_Analyzer::RDP_Analyzer(Connection* c)
 	: analyzer::Analyzer("RDPEUDP", c)
@@ -32,6 +34,8 @@ void RDP_Analyzer::DeliverPacket(int len, const u_char* data, bool orig,
 		}
 	catch ( const binpac::Exception& e )
 		{
-		ProtocolViolation(fmt("Binpac exception: %s", e.c_msg()));
+		ProtocolViolation(util::fmt("Binpac exception: %s", e.c_msg()));
 		}
 	}
+
+} // namespace zeek::analyzer::rdpeudp
