@@ -1,20 +1,18 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
-#include "RPC.h"
-
-#include <string>
-
-#include "NetVar.h"
-#include "XDR.h"
-#include "Reporter.h"
-#include "Sessions.h"
-
-#include "events.bif.h"
+#include "zeek/analyzer/protocol/rpc/RPC.h"
 
 #include <stdlib.h>
+#include <string>
 
-using namespace analyzer::rpc;
+#include "zeek/NetVar.h"
+#include "zeek/analyzer/protocol/rpc/XDR.h"
+#include "zeek/Reporter.h"
+#include "zeek/Sessions.h"
+#include "zeek/RunState.h"
+
+#include "analyzer/protocol/rpc/events.bif.h"
 
 namespace { // local namespace
 	const bool DEBUG_rpc_resync = false;
@@ -25,6 +23,8 @@ namespace { // local namespace
 // TODO: make this configurable
 #define MAX_RPC_LEN 65536
 
+namespace zeek::analyzer::rpc {
+namespace detail {
 
 RPC_CallInfo::RPC_CallInfo(uint32_t arg_xid, const u_char*& buf, int& n, double arg_start_time, double arg_last_time, int arg_rpc_len)
 	{
@@ -85,7 +85,7 @@ RPC_CallInfo::RPC_CallInfo(uint32_t arg_xid, const u_char*& buf, int& n, double
 			return;
 			}
 
-		for ( auto i = 0u; i < number_of_gids; ++i )
+		for ( size_t i = 0; i < number_of_gids; ++i )
 			auxgids.push_back(extract_XDR_uint32(cred_opaque, cred_opaque_n));
 		}
 
@@ -327,7 +327,7 @@ void RPC_Interpreter::Timeout()
 			const u_char* buf = nullptr;
 			int n = 0;
 
-			if ( ! RPC_BuildReply(c, BifEnum::RPC_TIMEOUT, buf, n, network_time, network_time, 0) )
+			if ( ! RPC_BuildReply(c, BifEnum::RPC_TIMEOUT, buf, n, run_state::network_time, run_state::network_time, 0) )
 				Weird("bad_RPC");
 			}
 		}
@@ -338,13 +338,13 @@ void RPC_Interpreter::Event_RPC_Dialogue(RPC_CallInfo* c, BifEnum::rpc_status st
 	if ( rpc_dialogue )
 		analyzer->EnqueueConnEvent(rpc_dialogue,
 			analyzer->ConnVal(),
-			zeek::val_mgr->Count(c->Program()),
-			zeek::val_mgr->Count(c->Version()),
-			zeek::val_mgr->Count(c->Proc()),
-			zeek::BifType::Enum::rpc_status->GetEnumVal(status),
-			zeek::make_intrusive<zeek::TimeVal>(c->StartTime()),
-			zeek::val_mgr->Count(c->CallLen()),
-			zeek::val_mgr->Count(reply_len)
+			val_mgr->Count(c->Program()),
+			val_mgr->Count(c->Version()),
+			val_mgr->Count(c->Proc()),
+			BifType::Enum::rpc_status->GetEnumVal(status),
+			make_intrusive<TimeVal>(c->StartTime()),
+			val_mgr->Count(c->CallLen()),
+			val_mgr->Count(reply_len)
 		);
 	}
 
@@ -353,11 +353,11 @@ void RPC_Interpreter::Event_RPC_Call(RPC_CallInfo* c)
 	if ( rpc_call )
 		analyzer->EnqueueConnEvent(rpc_call,
 			analyzer->ConnVal(),
-			zeek::val_mgr->Count(c->XID()),
-			zeek::val_mgr->Count(c->Program()),
-			zeek::val_mgr->Count(c->Version()),
-			zeek::val_mgr->Count(c->Proc()),
-			zeek::val_mgr->Count(c->CallLen())
+			val_mgr->Count(c->XID()),
+			val_mgr->Count(c->Program()),
+			val_mgr->Count(c->Version()),
+			val_mgr->Count(c->Proc()),
+			val_mgr->Count(c->CallLen())
 		);
 	}
 
@@ -366,9 +366,9 @@ void RPC_Interpreter::Event_RPC_Reply(uint32_t xid, BifEnum::rpc_status status,
 	if ( rpc_reply )
 		analyzer->EnqueueConnEvent(rpc_reply,
 			analyzer->ConnVal(),
-			zeek::val_mgr->Count(xid),
-			zeek::BifType::Enum::rpc_status->GetEnumVal(status),
-			zeek::val_mgr->Count(reply_len)
+			val_mgr->Count(xid),
+			BifType::Enum::rpc_status->GetEnumVal(status),
+			val_mgr->Count(reply_len)
 		);
 	}
 
@@ -412,9 +412,11 @@ bool RPC_Reasm_Buffer::ConsumeChunk(const u_char*& data, int& len)
 	return (expected == processed);
 	}
 
+} // namespace detail
+
 Contents_RPC::Contents_RPC(Connection* conn, bool orig,
-				RPC_Interpreter* arg_interp)
-	: tcp::TCP_SupportAnalyzer("CONTENTS_RPC", conn, orig)
+                           detail::RPC_Interpreter* arg_interp)
+	: analyzer::tcp::TCP_SupportAnalyzer("CONTENTS_RPC", conn, orig)
 	{
 	interp = arg_interp;
 	state = WAIT_FOR_MESSAGE;
@@ -426,7 +428,7 @@ Contents_RPC::Contents_RPC(Connection* conn, bool orig,
 
 void Contents_RPC::Init()
 	{
-	tcp::TCP_SupportAnalyzer::Init();
+	analyzer::tcp::TCP_SupportAnalyzer::Init();
 	}
 
 Contents_RPC::~Contents_RPC()
@@ -435,7 +437,7 @@ Contents_RPC::~Contents_RPC()
 
 void Contents_RPC::Undelivered(uint64_t seq, int len, bool orig)
 	{
-	tcp::TCP_SupportAnalyzer::Undelivered(seq, len, orig);
+	analyzer::tcp::TCP_SupportAnalyzer::Undelivered(seq, len, orig);
 	NeedResync();
 	}
 
@@ -454,12 +456,12 @@ bool Contents_RPC::CheckResync(int& len, const u_char*& data, bool orig)
 		// is fully established we are in sync (since it's the first chunk
 		// of data after the SYN if its not established we need to
 		// resync.
-		tcp::TCP_Analyzer* tcp =
-			static_cast<tcp::TCP_ApplicationAnalyzer*>(Parent())->TCP();
+		analyzer::tcp::TCP_Analyzer* tcp =
+			static_cast<analyzer::tcp::TCP_ApplicationAnalyzer*>(Parent())->TCP();
 		assert(tcp);
 
 		if ( (IsOrig() ? tcp->OrigState() : tcp->RespState()) !=
-							tcp::TCP_ENDPOINT_ESTABLISHED )
+							analyzer::tcp::TCP_ENDPOINT_ESTABLISHED )
 			{
 			NeedResync();
 			}
@@ -513,8 +515,8 @@ bool Contents_RPC::CheckResync(int& len, const u_char*& data, bool orig)
 		if ( resync_toskip != 0 )
 			{
 			// Should never happen.
-			reporter->AnalyzerError(this,
-			  "RPC resync: skipping over data failed");
+			reporter->AnalyzerError(
+				this, "RPC resync: skipping over data failed");
 			return false;
 			}
 
@@ -532,8 +534,8 @@ bool Contents_RPC::CheckResync(int& len, const u_char*& data, bool orig)
 				// TCP keep-alive retransmissions.
 				DEBUG_MSG("%.6f RPC resync: "
 						  "discard small pieces: %d\n",
-							  network_time, len);
-				Conn()->Weird("RPC_resync", fmt("discard %d bytes\n", len));
+							  run_state::network_time, len);
+				Conn()->Weird("RPC_resync", util::fmt("discard %d bytes\n", len));
 				}
 
 			NeedResync();
@@ -621,7 +623,7 @@ bool Contents_RPC::CheckResync(int& len, const u_char*& data, bool orig)
 
 void Contents_RPC::DeliverStream(int len, const u_char* data, bool orig)
 	{
-	tcp::TCP_SupportAnalyzer::DeliverStream(len, data, orig);
+	analyzer::tcp::TCP_SupportAnalyzer::DeliverStream(len, data, orig);
 	uint32_t marker;
 	bool last_frag;
 
@@ -632,7 +634,7 @@ void Contents_RPC::DeliverStream(int len, const u_char* data, bool orig)
 
 	while (len > 0)
 		{
-		last_time = network_time;
+		last_time = run_state::network_time;
 
 		switch (state) {
 		case WAIT_FOR_MESSAGE:
@@ -647,7 +649,7 @@ void Contents_RPC::DeliverStream(int len, const u_char* data, bool orig)
 			msg_buf.Init(MAX_RPC_LEN, 0);
 			last_frag = false;
 			state = WAIT_FOR_MARKER;
-			start_time = network_time;
+			start_time = run_state::network_time;
 			// no break. fall through
 
 		case WAIT_FOR_MARKER:
@@ -665,18 +667,18 @@ void Contents_RPC::DeliverStream(int len, const u_char* data, bool orig)
 
 				if ( ! dummy_p )
 					{
-					reporter->AnalyzerError(this,
-					  "inconsistent RPC record marker extraction");
+					reporter->AnalyzerError(
+						this, "inconsistent RPC record marker extraction");
 					return;
 					}
 
 				last_frag = (marker & 0x80000000) != 0;
 				marker &= 0x7fffffff;
 					//printf("%.6f %d marker= %u <> last_frag= %d <> expected=%llu <> processed= %llu <> len = %d\n",
-					//		network_time, IsOrig(), marker, last_frag, msg_buf.GetExpected(), msg_buf.GetProcessed(), len);
+					//		run_state::network_time, IsOrig(), marker, last_frag, msg_buf.GetExpected(), msg_buf.GetProcessed(), len);
 
 				if ( ! msg_buf.AddToExpected(marker) )
-					Conn()->Weird("RPC_message_too_long", fmt("%" PRId64, msg_buf.GetExpected()));
+					Conn()->Weird("RPC_message_too_long", util::fmt("%" PRId64, msg_buf.GetExpected()));
 
 				if ( last_frag )
 					state = WAIT_FOR_LAST_DATA;
@@ -721,13 +723,14 @@ void Contents_RPC::DeliverStream(int len, const u_char* data, bool orig)
 	}
 
 RPC_Analyzer::RPC_Analyzer(const char* name, Connection* conn,
-				RPC_Interpreter* arg_interp)
-	: tcp::TCP_ApplicationAnalyzer(name, conn),
+                           detail::RPC_Interpreter* arg_interp)
+	: analyzer::tcp::TCP_ApplicationAnalyzer(name, conn),
 	  interp(arg_interp), orig_rpc(), resp_rpc()
 	{
 	if ( Conn()->ConnTransport() == TRANSPORT_UDP )
 		ADD_ANALYZER_TIMER(&RPC_Analyzer::ExpireTimer,
-			network_time + rpc_timeout, true, TIMER_RPC_EXPIRE);
+		                   run_state::network_time + zeek::detail::rpc_timeout, true,
+		                   zeek::detail::TIMER_RPC_EXPIRE);
 	}
 
 RPC_Analyzer::~RPC_Analyzer()
@@ -736,26 +739,26 @@ RPC_Analyzer::~RPC_Analyzer()
 	}
 
 void RPC_Analyzer::DeliverPacket(int len, const u_char* data, bool orig,
-					uint64_t seq, const IP_Hdr* ip, int caplen)
+                                 uint64_t seq, const IP_Hdr* ip, int caplen)
 	{
-	tcp::TCP_ApplicationAnalyzer::DeliverPacket(len, data, orig, seq, ip, caplen);
+	analyzer::tcp::TCP_ApplicationAnalyzer::DeliverPacket(len, data, orig, seq, ip, caplen);
 	len = std::min(len, caplen);
 
 	if ( orig )
 		{
-		if ( ! interp->DeliverRPC(data, len, len, true, network_time, network_time) )
+		if ( ! interp->DeliverRPC(data, len, len, true, run_state::network_time, run_state::network_time) )
 			Weird("bad_RPC");
 		}
 	else
 		{
-		if ( ! interp->DeliverRPC(data, len, len, false, network_time, network_time) )
+		if ( ! interp->DeliverRPC(data, len, len, false, run_state::network_time, run_state::network_time) )
 			Weird("bad_RPC");
 		}
 	}
 
 void RPC_Analyzer::Done()
 	{
-	tcp::TCP_ApplicationAnalyzer::Done();
+	analyzer::tcp::TCP_ApplicationAnalyzer::Done();
 
 	interp->Timeout();
 	}
@@ -765,3 +768,5 @@ void RPC_Analyzer::ExpireTimer(double /* t */)
 	Event(connection_timeout);
 	sessions->Remove(Conn());
 	}
+
+} // namespace zeek::analyzer::rpc
