@@ -1,26 +1,17 @@
+// See the file "COPYING" in the main distribution directory for copyright.
 
-#include "FileReassembler.h"
-#include "File.h"
+#include "zeek/file_analysis/FileReassembler.h"
+#include "zeek/file_analysis/File.h"
 
+ZEEK_FORWARD_DECLARE_NAMESPACED(File, zeek, file_analysis);
 
-namespace file_analysis {
-
-class File;
+namespace zeek::file_analysis {
 
 FileReassembler::FileReassembler(File *f, uint64_t starting_offset)
 	: Reassembler(starting_offset, REASSEM_FILE), the_file(f), flushing(false)
 	{
 	}
 
-FileReassembler::FileReassembler()
-	: Reassembler(), the_file(nullptr), flushing(false)
-	{
-	}
-
-FileReassembler::~FileReassembler()
-	{
-	}
-
 uint64_t FileReassembler::Flush()
 	{
 	if ( flushing )
