@@ -12,6 +12,7 @@
  */
 
 #include "zeek-config.h"			/* must appear before first ifdef */
+#include "zeek/nb_dns.h"
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -42,8 +43,6 @@
 #endif
 #endif
 
-#include "nb_dns.h"
-
 #if PACKETSZ > 1024
 #define MAXPACKET	PACKETSZ
 #else
@@ -61,10 +60,10 @@ extern int recvfrom(int, void *, int, int, struct sockaddr *, int *);
 struct nb_dns_entry {
 	struct nb_dns_entry *next;
 	char name[NS_MAXDNAME + 1];
+	u_short id;
 	int qtype;			/* query type */
 	int atype;			/* address family */
 	int asize;			/* address size */
-	u_short id;
 	void *cookie;
 };
 
@@ -411,7 +410,7 @@ _nb_dns_mkquery(register struct nb_dns_info *nd, register const char *name,
 		return (-1);
 	}
 	memset(ne, 0, sizeof(*ne));
-	strncpy(ne->name, name, sizeof(ne->name));
+	strncpy(ne->name, name, sizeof(ne->name) - 1);
 	ne->name[sizeof(ne->name) - 1] = '\0';
 	ne->qtype = qtype;
 	ne->atype = atype;
