@@ -1,21 +1,62 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
+#include "zeek/net_util.h"
 
 #include <sys/types.h>
 #include <sys/socket.h>
-
 #include <netinet/in.h>
-
 #include <arpa/inet.h>
 
-#include "Reporter.h"
-#include "net_util.h"
-#include "IPAddr.h"
-#include "IP.h"
+#include "zeek/Reporter.h"
+#include "zeek/IPAddr.h"
+#include "zeek/IP.h"
 
-// - adapted from tcpdump
-// Returns the ones-complement checksum of a chunk of b short-aligned bytes.
+namespace zeek {
+
+uint16_t detail::ip4_in_cksum(const IPAddr& src, const IPAddr& dst,
+                              uint8_t next_proto, const uint8_t* data, int len)
+	{
+	constexpr auto nblocks = 2;
+	detail::checksum_block blocks[nblocks];
+
+	ipv4_pseudo_hdr ph;
+	memset(&ph, 0, sizeof(ph));
+
+	src.CopyIPv4(&ph.src);
+	dst.CopyIPv4(&ph.dst);
+	ph.len = htons(static_cast<uint16_t>(len));
+	ph.next_proto = next_proto;
+	blocks[0].block = reinterpret_cast<const uint8_t*>(&ph);
+	blocks[0].len = sizeof(ph);
+	blocks[1].block = data;
+	blocks[1].len = len;
+
+	return in_cksum(blocks, nblocks);
+	}
+
+uint16_t detail::ip6_in_cksum(const IPAddr& src, const IPAddr& dst,
+                              uint8_t next_proto, const uint8_t* data, int len)
+	{
+	constexpr auto nblocks = 2;
+	detail::checksum_block blocks[nblocks];
+
+	ipv6_pseudo_hdr ph;
+	memset(&ph, 0, sizeof(ph));
+
+	src.CopyIPv6(&ph.src);
+	dst.CopyIPv6(&ph.dst);
+	ph.len = htonl(static_cast<uint32_t>(len));
+	ph.next_proto = next_proto;
+	blocks[0].block = reinterpret_cast<const uint8_t*>(&ph);
+	blocks[0].len = sizeof(ph);
+	blocks[1].block = data;
+	blocks[1].len = len;
+
+	return in_cksum(blocks, nblocks);
+	}
+
+// Returns the ones-complement checksum of a chunk of 'b' bytes.
 int ones_complement_checksum(const void* p, int b, uint32_t sum)
 	{
 	const unsigned char* sp = (unsigned char*) p;
@@ -44,17 +85,7 @@ int ones_complement_checksum(const IPAddr& a, uint32_t sum)
 
 int icmp_checksum(const struct icmp* icmpp, int len)
 	{
-	uint32_t sum;
-
-	if ( len % 2 == 1 )
-		// Add in pad byte.
-		sum = htons(((const u_char*) icmpp)[len - 1] << 8);
-	else
-		sum = 0;
-
-	sum = ones_complement_checksum((void*) icmpp, len, sum);
-
-	return sum;
+	return detail::in_cksum(reinterpret_cast<const uint8_t*>(icmpp), len);
 	}
 
 #ifdef ENABLE_MOBILE_IPV6
@@ -87,26 +118,8 @@ int icmp6_checksum(const struct icmp* icmpp, const IP_Hdr* ip, int len)
 	{
 	// ICMP6 uses the same checksum function as ICMP4 but a different
 	// pseudo-header over which it is computed.
-	uint32_t sum;
-
-	if ( len % 2 == 1 )
-		// Add in pad byte.
-		sum = htons(((const u_char*) icmpp)[len - 1] << 8);
-	else
-		sum = 0;
-
-	// Pseudo-header as for UDP over IPv6 above.
-	sum = ones_complement_checksum(ip->SrcAddr(), sum);
-	sum = ones_complement_checksum(ip->DstAddr(), sum);
-	uint32_t l = htonl(len);
-	sum = ones_complement_checksum((void*) &l, 4, sum);
-
-	uint32_t addl_pseudo = htons(IPPROTO_ICMPV6);
-	sum = ones_complement_checksum((void*) &addl_pseudo, 4, sum);
-
-	sum = ones_complement_checksum((void*) icmpp, len, sum);
-
-	return sum;
+	return detail::ip6_in_cksum(ip->SrcAddr(), ip->DstAddr(), IPPROTO_ICMPV6,
+	                            reinterpret_cast<const uint8_t*>(icmpp), len);
 	}
 
 
@@ -132,7 +145,7 @@ char addr_to_class(uint32_t addr)
 	}
 
 const char* fmt_conn_id(const IPAddr& src_addr, uint32_t src_port,
-			const IPAddr& dst_addr, uint32_t dst_port)
+                        const IPAddr& dst_addr, uint32_t dst_port)
 	{
 	static char buffer[512];
 
@@ -144,7 +157,7 @@ const char* fmt_conn_id(const IPAddr& src_addr, uint32_t src_port,
 	}
 
 const char* fmt_conn_id(const uint32_t* src_addr, uint32_t src_port,
-			const uint32_t* dst_addr, uint32_t dst_port)
+                        const uint32_t* dst_addr, uint32_t dst_port)
 	{
 	IPAddr src(IPv6, src_addr, IPAddr::Network);
 	IPAddr dst(IPv6, dst_addr, IPAddr::Network);
@@ -182,3 +195,5 @@ uint32_t extract_uint32(const u_char* data)
 
 	return val;
 	}
+
+} // namespace zeek
