@@ -1,26 +1,30 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include <sstream>
-#include <fstream>
+#include "zeek/plugin/Manager.h"
+
 #include <dirent.h>
 #include <glob.h>
 #include <dlfcn.h>
 #include <errno.h>
 #include <sys/stat.h>
+#include <optional>
+#include <sstream>
+#include <fstream>
 
-#include "Manager.h"
+#include "zeek/Reporter.h"
+#include "zeek/Func.h"
+#include "zeek/Event.h"
+#include "zeek/Val.h"
+#include "zeek/util.h"
+#include "zeek/input.h"
 
-#include "../Reporter.h"
-#include "../Func.h"
-#include "../Event.h"
-#include "../util.h"
-#include "../input.h"
+using namespace std;
 
-using namespace plugin;
+namespace zeek::plugin {
 
-Plugin* Manager::current_plugin = 0;
-const char* Manager::current_dir = 0;
-const char* Manager::current_sopath = 0;
+Plugin* Manager::current_plugin = nullptr;
+const char* Manager::current_dir = nullptr;
+const char* Manager::current_sopath = nullptr;
 
 Manager::Manager()
 	{
@@ -28,7 +32,7 @@ Manager::Manager()
 	hooks = new hook_list*[NUM_HOOKS];
 
 	for ( int i = 0; i < NUM_HOOKS; i++ )
-		hooks[i] = 0;
+		hooks[i] = nullptr;
 	}
 
 Manager::~Manager()
@@ -48,7 +52,7 @@ void Manager::SearchDynamicPlugins(const std::string& dir)
 	if ( dir.empty() )
 		return;
 
-	if ( dir.find(":") != string::npos )
+	if ( dir.find(':') != string::npos )
 		{
 		// Split at ":".
 		std::stringstream s(dir);
@@ -60,7 +64,7 @@ void Manager::SearchDynamicPlugins(const std::string& dir)
 		return;
 		}
 
-	if ( ! is_dir(dir) )
+	if ( ! util::is_dir(dir) )
 		{
 		DBG_LOG(DBG_PLUGINS, "Not a valid plugin directory: %s", dir.c_str());
 		return;
@@ -70,7 +74,7 @@ void Manager::SearchDynamicPlugins(const std::string& dir)
 
 	const std::string magic = dir + "/__bro_plugin__";
 
-	if ( is_file(magic) )
+	if ( util::is_file(magic) )
 		{
 		// It's a plugin, get it's name.
 		std::ifstream in(magic.c_str());
@@ -80,8 +84,8 @@ void Manager::SearchDynamicPlugins(const std::string& dir)
 
 		std::string name;
 		std::getline(in, name);
-		strstrip(name);
-		string lower_name = strtolower(name);
+		util::strstrip(name);
+		string lower_name = util::strtolower(name);
 
 		if ( name.empty() )
 			reporter->FatalError("empty plugin magic file %s", magic.c_str());
@@ -136,9 +140,11 @@ void Manager::SearchDynamicPlugins(const std::string& dir)
 	closedir(d);
 	}
 
-bool Manager::ActivateDynamicPluginInternal(const std::string& name, bool ok_if_not_found)
+bool Manager::ActivateDynamicPluginInternal(const std::string& name, bool ok_if_not_found, std::vector<std::string>* errors)
 	{
-	dynamic_plugin_map::iterator m = dynamic_plugins.find(strtolower(name));
+	errors->clear(); // caller should pass it in empty, but just to be sure
+
+	dynamic_plugin_map::iterator m = dynamic_plugins.find(util::strtolower(name));
 
 	if ( m == dynamic_plugins.end() )
 		{
@@ -150,13 +156,13 @@ bool Manager::ActivateDynamicPluginInternal(const std::string& name, bool ok_if_
 		// this should be rare to begin with.
 		plugin_list* all_plugins = Manager::ActivePluginsInternal();
 
-		for ( plugin::Manager::plugin_list::const_iterator i = all_plugins->begin(); i != all_plugins->end(); i++ )
+		for ( Manager::plugin_list::const_iterator i = all_plugins->begin(); i != all_plugins->end(); i++ )
 			{
 			if ( (*i)->Name() == name )
 				return true;
 			}
 
-		reporter->Error("plugin %s is not available", name.c_str());
+		errors->push_back(util::fmt("plugin %s is not available", name.c_str()));
 		return false;
 		}
 
@@ -171,58 +177,6 @@ bool Manager::ActivateDynamicPluginInternal(const std::string& name, bool ok_if_
 
 	DBG_LOG(DBG_PLUGINS, "Activating plugin %s", name.c_str());
 
-	// Add the "scripts" and "bif" directories to ZEEKPATH.
-	std::string scripts = dir + "scripts";
-
-	if ( is_dir(scripts) )
-		{
-		DBG_LOG(DBG_PLUGINS, "  Adding %s to ZEEKPATH", scripts.c_str());
-		add_to_bro_path(scripts);
-		}
-
-	string init;
-
-	// First load {scripts}/__preload__.zeek automatically.
-	for (const string& ext : script_extensions)
-		{
-		init = dir + "scripts/__preload__" + ext;
-
-		if ( is_file(init) )
-			{
-			DBG_LOG(DBG_PLUGINS, "  Loading %s", init.c_str());
-			warn_if_legacy_script(init);
-			scripts_to_load.push_back(init);
-			break;
-			}
-		}
-
-	// Load {bif,scripts}/__load__.zeek automatically.
-	for (const string& ext : script_extensions)
-		{
-		init = dir + "lib/bif/__load__" + ext;
-
-		if ( is_file(init) )
-			{
-			DBG_LOG(DBG_PLUGINS, "  Loading %s", init.c_str());
-			warn_if_legacy_script(init);
-			scripts_to_load.push_back(init);
-			break;
-			}
-		}
-
-	for (const string& ext : script_extensions)
-		{
-		init = dir + "scripts/__load__" + ext;
-
-		if ( is_file(init) )
-			{
-			DBG_LOG(DBG_PLUGINS, "  Loading %s", init.c_str());
-			warn_if_legacy_script(init);
-			scripts_to_load.push_back(init);
-			break;
-			}
-		}
-
 	// Load shared libraries.
 
 	string dypattern = dir + "/lib/*." + HOST_ARCHITECTURE + DYNAMIC_PLUGIN_SUFFIX;
@@ -237,26 +191,31 @@ bool Manager::ActivateDynamicPluginInternal(const std::string& name, bool ok_if_
 			{
 			const char* path = gl.gl_pathv[i];
 
-			current_plugin = 0;
+			current_plugin = nullptr;
 			current_dir = dir.c_str();
 			current_sopath = path;
-			void* hdl = dlopen(path, RTLD_LAZY | RTLD_GLOBAL);
+			void* hdl = dlopen(path, RTLD_NOW | RTLD_GLOBAL);
+			current_dir = nullptr;
+			current_sopath = nullptr;
 
 			if ( ! hdl )
 				{
 				const char* err = dlerror();
-				reporter->FatalError("cannot load plugin library %s: %s", path, err ? err : "<unknown error>");
+				errors->push_back(util::fmt("cannot load plugin library %s: %s", path, err ? err : "<unknown error>"));
+				continue;
 				}
 
-			if ( ! current_plugin )
-				reporter->FatalError("load plugin library %s did not instantiate a plugin", path);
+			if ( ! current_plugin ) {
+				errors->push_back(util::fmt("load plugin library %s did not instantiate a plugin", path));
+				continue;
+			}
 
 			current_plugin->SetDynamic(true);
 			current_plugin->DoConfigure();
 			DBG_LOG(DBG_PLUGINS, "  InitialzingComponents");
 			current_plugin->InitializeComponents();
 
-			plugins_by_path.insert(std::make_pair(normalize_path(dir), current_plugin));
+			plugins_by_path.insert(std::make_pair(util::detail::normalize_path(dir), current_plugin));
 
 			// We execute the pre-script initialization here; this in
 			// fact could be *during* script initialization if we got
@@ -265,18 +224,20 @@ bool Manager::ActivateDynamicPluginInternal(const std::string& name, bool ok_if_
 
 			// Make sure the name the plugin reports is consistent with
 			// what we expect from its magic file.
-			if ( strtolower(current_plugin->Name()) != strtolower(name) )
-				reporter->FatalError("inconsistent plugin name: %s vs %s",
-						     current_plugin->Name().c_str(), name.c_str());
-
-			current_dir = 0;
-			current_sopath = 0;
-			current_plugin = 0;
+			if ( util::strtolower(current_plugin->Name()) != util::strtolower(name) ) {
+				errors->push_back(util::fmt("inconsistent plugin name: %s vs %s",
+						     current_plugin->Name().c_str(), name.c_str()));
+				continue;
+			}
 
+			current_plugin = nullptr;
 			DBG_LOG(DBG_PLUGINS, "  Loaded %s", path);
 			}
 
 		globfree(&gl);
+
+		if ( ! errors->empty() )
+			return false;
 		}
 
 	else
@@ -284,43 +245,124 @@ bool Manager::ActivateDynamicPluginInternal(const std::string& name, bool ok_if_
 		DBG_LOG(DBG_PLUGINS, "  No shared library found");
 		}
 
+	// Add the "scripts" and "bif" directories to ZEEKPATH.
+	std::string scripts = dir + "scripts";
+
+	if ( util::is_dir(scripts) )
+		{
+		DBG_LOG(DBG_PLUGINS, "  Adding %s to ZEEKPATH", scripts.c_str());
+		util::detail::add_to_zeek_path(scripts);
+		}
+
+	string init;
+
+	// First load {scripts}/__preload__.zeek automatically.
+	for (const string& ext : util::detail::script_extensions)
+		{
+		init = dir + "scripts/__preload__" + ext;
+
+		if ( util::is_file(init) )
+			{
+			DBG_LOG(DBG_PLUGINS, "  Loading %s", init.c_str());
+			util::detail::warn_if_legacy_script(init);
+			scripts_to_load.push_back(init);
+			break;
+			}
+		}
+
+	// Load {bif,scripts}/__load__.zeek automatically.
+	for (const string& ext : util::detail::script_extensions)
+		{
+		init = dir + "lib/bif/__load__" + ext;
+
+		if ( util::is_file(init) )
+			{
+			DBG_LOG(DBG_PLUGINS, "  Loading %s", init.c_str());
+			util::detail::warn_if_legacy_script(init);
+			scripts_to_load.push_back(init);
+			break;
+			}
+		}
+
+	for (const string& ext : util::detail::script_extensions)
+		{
+		init = dir + "scripts/__load__" + ext;
+
+		if ( util::is_file(init) )
+			{
+			DBG_LOG(DBG_PLUGINS, "  Loading %s", init.c_str());
+			util::detail::warn_if_legacy_script(init);
+			scripts_to_load.push_back(init);
+			break;
+			}
+		}
+
 	// Mark this plugin as activated by clearing the path.
 	m->second.clear();
 
 	return true;
 	}
 
-bool Manager::ActivateDynamicPlugin(const std::string& name)
+void Manager::ActivateDynamicPlugin(const std::string& name)
 	{
-	if ( ! ActivateDynamicPluginInternal(name) )
-		return false;
-
-	UpdateInputFiles();
-	return true;
+	std::vector<std::string> errors;
+	if ( ActivateDynamicPluginInternal(name, false, &errors) )
+		UpdateInputFiles();
+	else
+		// Reschedule for another attempt later.
+		requested_plugins.insert(std::move(name));
 	}
 
-bool Manager::ActivateDynamicPlugins(bool all)
-	{
+void Manager::ActivateDynamicPlugins(bool all) {
+	// Tracks plugins we need to activate as pairs of their names and booleans
+	// indicating whether an activation failure is to be deemed a fatal error.
+	std::set<std::pair<std::string, bool>> plugins_to_activate;
+
+	// Activate plugins that were specifically requested.
+	for ( const auto& x : requested_plugins )
+		plugins_to_activate.emplace(x, false);
+
 	// Activate plugins that our environment tells us to.
 	vector<string> p;
-	tokenize_string(bro_plugin_activate(), ",", &p);
+	util::tokenize_string(util::zeek_plugin_activate(), ",", &p);
 
-	for ( size_t n = 0; n < p.size(); ++n )
-		ActivateDynamicPluginInternal(p[n], true);
+	for ( const auto& x : p )
+		plugins_to_activate.emplace(x, true);
 
 	if ( all )
 		{
-		for ( dynamic_plugin_map::const_iterator i = dynamic_plugins.begin();
-		      i != dynamic_plugins.end(); i++ )
+		// Activate all other ones we discovered.
+		for ( const auto& x : dynamic_plugins )
+			plugins_to_activate.emplace(x.first, false);
+		}
+
+	// Now we keep iterating over all the plugins, trying to load them, for as
+	// long as we're successful for at least one further of them each round.
+	// Doing so ensures that we can resolve (non-cyclic) load dependencies
+	// independent of any particular order.
+	while ( ! plugins_to_activate.empty() ) {
+		std::vector<std::string> errors;
+		auto plugins_left = plugins_to_activate;
+
+		for ( const auto& x : plugins_to_activate )
 			{
-			if ( ! ActivateDynamicPluginInternal(i->first) )
-				return false;
+			if ( ActivateDynamicPluginInternal(x.first, x.second, &errors) )
+				plugins_left.erase(x);
 			}
+
+		if ( plugins_left.size() == plugins_to_activate.size() )
+			{
+			// Could not load a single further plugin this round, that's fatal.
+			for ( const auto& msg : errors )
+				reporter->Error("%s", msg.c_str());
+
+			reporter->FatalError("aborting after plugin errors");
+			}
+
+		plugins_to_activate = std::move(plugins_left);
 		}
 
 	UpdateInputFiles();
-
-	return true;
 	}
 
 void Manager::UpdateInputFiles()
@@ -334,7 +376,7 @@ void Manager::UpdateInputFiles()
 
 static bool plugin_cmp(const Plugin* a, const Plugin* b)
 	{
-	return strtolower(a->Name()) < strtolower(b->Name());
+	return util::strtolower(a->Name()) < util::strtolower(b->Name());
 	}
 
 void Manager::RegisterPlugin(Plugin *plugin)
@@ -343,7 +385,7 @@ void Manager::RegisterPlugin(Plugin *plugin)
 
 	if ( current_dir && current_sopath )
 		// A dynamic plugin, record its location.
-		plugin->SetPluginLocation(normalize_path(current_dir), current_sopath);
+		plugin->SetPluginLocation(util::detail::normalize_path(current_dir), current_sopath);
 
 	current_plugin = plugin;
 	}
@@ -352,7 +394,7 @@ void Manager::RegisterBifFile(const char* plugin, bif_init_func c)
 	{
 	bif_init_func_map* bifs = BifFilesInternal();
 
-	std::string lower_plugin = strtolower(plugin);
+	std::string lower_plugin = util::strtolower(plugin);
 	bif_init_func_map::iterator i = bifs->find(lower_plugin);
 
 	if ( i == bifs->end() )
@@ -395,7 +437,7 @@ void Manager::InitBifs()
 	for ( plugin_list::iterator i = Manager::ActivePluginsInternal()->begin();
 	      i != Manager::ActivePluginsInternal()->end(); i++ )
 		{
-		bif_init_func_map::const_iterator b = bifs->find(strtolower((*i)->Name()));
+		bif_init_func_map::const_iterator b = bifs->find(util::strtolower((*i)->Name()));
 
 		if ( b != bifs->end() )
 			{
@@ -444,7 +486,7 @@ Manager::inactive_plugin_list Manager::InactivePlugins() const
 
 		for ( plugin_list::const_iterator j = all->begin(); j != all->end(); j++ )
 			{
-			if ( (*i).first == strtolower((*j)->Name()) )
+			if ( (*i).first == util::strtolower((*j)->Name()) )
 				{
 				found = true;
 				break;
@@ -460,7 +502,7 @@ Manager::inactive_plugin_list Manager::InactivePlugins() const
 
 Manager::plugin_list* Manager::ActivePluginsInternal()
 	{
-	static plugin_list* plugins = 0;
+	static plugin_list* plugins = nullptr;
 
 	if ( ! plugins )
 		plugins = new plugin_list;
@@ -470,7 +512,7 @@ Manager::plugin_list* Manager::ActivePluginsInternal()
 
 Manager::bif_init_func_map* Manager::BifFilesInternal()
 	{
-	static bif_init_func_map* bifs = 0;
+	static bif_init_func_map* bifs = nullptr;
 
 	if ( ! bifs )
 		bifs = new bif_init_func_map;
@@ -480,10 +522,10 @@ Manager::bif_init_func_map* Manager::BifFilesInternal()
 
 Plugin* Manager::LookupPluginByPath(std::string_view _path)
 	{
-	auto path = normalize_path(_path);
+	auto path = util::detail::normalize_path(_path);
 
-	if ( is_file(path) )
-		path = SafeDirname(path).result;
+	if ( util::is_file(path) )
+		path = util::SafeDirname(path).result;
 
 	while ( path.size() )
 		{
@@ -492,7 +534,7 @@ Plugin* Manager::LookupPluginByPath(std::string_view _path)
 		if ( i != plugins_by_path.end() )
 			return i->second;
 
-		auto j = path.rfind("/");
+		auto j = path.rfind('/');
 
 		if ( j == std::string::npos )
 			break;
@@ -506,7 +548,7 @@ Plugin* Manager::LookupPluginByPath(std::string_view _path)
 static bool hook_cmp(std::pair<int, Plugin*> a, std::pair<int, Plugin*> b)
 	{
 	if ( a.first == b.first )
-		return strtolower(a.second->Name()) < strtolower(a.second->Name());
+		return util::strtolower(a.second->Name()) < util::strtolower(a.second->Name());
 
 	// Reverse sort.
 	return a.first > b.first;
@@ -518,16 +560,10 @@ std::list<std::pair<HookType, int> > Manager::HooksEnabledForPlugin(const Plugin
 
 	for ( int i = 0; i < NUM_HOOKS; i++ )
 		{
-		hook_list* l = hooks[i];
-
-		if ( ! l )
-			continue;
-
-		for ( hook_list::iterator j = l->begin(); j != l->end(); j++ )
-			{
-			if ( (*j).second == plugin )
-				enabled.push_back(std::make_pair((HookType)i, (*j).first));
-			}
+		if ( hook_list* l = hooks[i] )
+			for ( const auto& [hook, hook_plugin] : *l )
+				if ( hook_plugin == plugin )
+					enabled.push_back(std::make_pair(static_cast<HookType>(i), hook));
 		}
 
 	return enabled;
@@ -570,7 +606,7 @@ void Manager::DisableHook(HookType hook, Plugin* plugin)
 	if ( l->empty() )
 		{
 		delete l;
-		hooks[hook] = 0;
+		hooks[hook] = nullptr;
 		}
 	}
 
@@ -581,7 +617,7 @@ void Manager::RequestEvent(EventHandlerPtr handler, Plugin* plugin)
 	handler->SetGenerateAlways();
 	}
 
-void Manager::RequestBroObjDtor(BroObj* obj, Plugin* plugin)
+void Manager::RequestBroObjDtor(Obj* obj, Plugin* plugin)
 	{
 	obj->NotifyPluginsOnDtor();
 	}
@@ -619,21 +655,29 @@ int Manager::HookLoadFile(const Plugin::LoadType type, const string& file, const
 	return rc;
 	}
 
-std::pair<bool, Val*> Manager::HookCallFunction(const Func* func, Frame* parent, val_list* vargs) const
+std::pair<bool, ValPtr>
+Manager::HookCallFunction(const Func* func, zeek::detail::Frame* parent,
+                          Args* vecargs) const
 	{
 	HookArgumentList args;
+	ValPList vargs;
 
 	if ( HavePluginForHook(META_HOOK_PRE) )
 		{
+		vargs.resize(vecargs->size());
+
+		for ( const auto& v : *vecargs )
+			vargs.push_back(v.get());
+
 		args.push_back(HookArgument(func));
 		args.push_back(HookArgument(parent));
-		args.push_back(HookArgument(vargs));
+		args.push_back(HookArgument(&vargs));
 		MetaHookPre(HOOK_CALL_FUNCTION, args);
 		}
 
 	hook_list* l = hooks[HOOK_CALL_FUNCTION];
 
-	std::pair<bool, Val*> v = std::pair<bool, Val*>(false, NULL);
+	std::pair<bool, ValPtr> rval{false, nullptr};
 
 	if ( l )
 		{
@@ -641,17 +685,18 @@ std::pair<bool, Val*> Manager::HookCallFunction(const Func* func, Frame* parent,
 			{
 			Plugin* p = (*i).second;
 
-			v = p->HookCallFunction(func, parent, vargs);
+			rval = p->HookFunctionCall(func, parent, vecargs);
 
-			if ( v.first )
+			if ( rval.first )
 				break;
 			}
 		}
 
 	if ( HavePluginForHook(META_HOOK_POST) )
-		MetaHookPost(HOOK_CALL_FUNCTION, args, HookArgument(v));
+		MetaHookPost(HOOK_CALL_FUNCTION, args,
+		             HookArgument(std::make_pair(rval.first, rval.second.get())));
 
-	return v;
+	return rval;
 	}
 
 bool Manager::HookQueueEvent(Event* event) const
@@ -859,9 +904,10 @@ bool Manager::HookLogWrite(const std::string& writer,
 	}
 
 bool Manager::HookReporter(const std::string& prefix, const EventHandlerPtr event,
-			   const Connection* conn, const val_list* addl, bool location,
-			   const Location* location1, const Location* location2,
-			   bool time, const std::string& message)
+                           const Connection* conn, const ValPList* addl, bool location,
+                           const zeek::detail::Location* location1,
+                           const zeek::detail::Location* location2,
+                           bool time, const std::string& message)
 
 	{
 	HookArgumentList args;
@@ -906,24 +952,16 @@ bool Manager::HookReporter(const std::string& prefix, const EventHandlerPtr even
 
 void Manager::MetaHookPre(HookType hook, const HookArgumentList& args) const
 	{
-	hook_list* l = hooks[HOOK_CALL_FUNCTION];
-
-	if ( l )
-		for ( hook_list::iterator i = l->begin(); i != l->end(); ++i )
-			{
-			Plugin* p = (*i).second;
-			p->MetaHookPre(hook, args);
-			}
+	if ( hook_list* l = hooks[HOOK_CALL_FUNCTION] )
+		for ( const auto& [hook_type, plugin] : *l )
+			plugin->MetaHookPre(hook, args);
 	}
 
 void Manager::MetaHookPost(HookType hook, const HookArgumentList& args, HookArgument result) const
 	{
-	hook_list* l = hooks[HOOK_CALL_FUNCTION];
-
-	if ( l )
-		for ( hook_list::iterator i = l->begin(); i != l->end(); ++i )
-			{
-			Plugin* p = (*i).second;
-			p->MetaHookPost(hook, args, result);
-			}
+	if ( hook_list* l = hooks[HOOK_CALL_FUNCTION] )
+		for ( const auto& [hook_type, plugin] : *l )
+			plugin->MetaHookPost(hook, args, result);
 	}
+
+} // namespace zeek::plugin
