@@ -1,16 +1,18 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#ifndef PLUGIN_MANAGER_H
-#define PLUGIN_MANAGER_H
+#pragma once
 
-#include <utility>
 #include <map>
+#include <set>
+#include <string_view>
+#include <utility>
 
-#include "Plugin.h"
-#include "Component.h"
-
-#include "../Reporter.h"
+#include "zeek/plugin/Plugin.h"
+#include "zeek/plugin/Component.h"
+#include "zeek/Reporter.h"
+#include "zeek/ZeekArgs.h"
 
+namespace zeek {
 namespace plugin {
 
 // Macros that trigger plugin hooks. We put this into macros to short-cut the
@@ -24,7 +26,7 @@ namespace plugin {
  * @param method_call The \a Manager method corresponding to the hook.
  */
 #define PLUGIN_HOOK_VOID(hook, method_call) \
-	{ if ( plugin_mgr->HavePluginForHook(plugin::hook) ) plugin_mgr->method_call; }
+	{ if ( zeek::plugin_mgr->HavePluginForHook(zeek::plugin::hook) ) zeek::plugin_mgr->method_call; }
 
 /**
  * Macro to trigger hooks that return a result.
@@ -37,7 +39,7 @@ namespace plugin {
  * the hook.
  */
 #define PLUGIN_HOOK_WITH_RESULT(hook, method_call, default_result) \
-	(plugin_mgr->HavePluginForHook(::plugin::hook) ? plugin_mgr->method_call : (default_result))
+	(zeek::plugin_mgr->HavePluginForHook(zeek::plugin::hook) ? zeek::plugin_mgr->method_call : (default_result))
 
 /**
  * A singleton object managing all plugins.
@@ -46,9 +48,9 @@ class Manager
 {
 public:
 	typedef void (*bif_init_func)(Plugin *);
-	typedef std::list<Plugin*> plugin_list;
-	typedef Plugin::component_list component_list;
-	typedef std::list<std::pair<std::string, std::string> > inactive_plugin_list;
+	using plugin_list = std::list<Plugin*>;
+	using component_list = Plugin::component_list;
+	using inactive_plugin_list = std::list<std::pair<std::string, std::string>>;
 
 	/**
 	 * Constructor.
@@ -78,28 +80,25 @@ public:
 	 * Activating a plugin involves loading its dynamic module, making its
 	 * bifs available, and adding its script paths to ZEEKPATH.
 	 *
+	 * This attempts to activate the plugin immediately. If that fails for
+	 * some reason, we schedule it to be retried later with
+	 * ActivateDynamicPlugins().
+	 *
 	 * @param name The name of the plugin, as found previously by
-	 * SearchPlugin().
-	 *
-	 * @return True if the plugin has been loaded successfully.
-	 *
+	·* SearchPlugin().
 	 */
-	bool ActivateDynamicPlugin(const std::string& name);
+	void ActivateDynamicPlugin(const std::string& name);
 
 	/**
-	 * Activates plugins that SearchDynamicPlugins() has previously discovered.
-	 * The effect is the same all calling \a ActivePlugin(name) for each plugin.
+	 * Activates plugins that SearchDynamicPlugins() has previously discovered,
+	 * including any that have failed to load in prior calls to
+	 * ActivateDynamicPlugin(). Aborts if any plugins fails to activate.
 	 *
 	 * @param all If true, activates all plugins that are found. If false,
 	 * activates only those that should always be activated unconditionally,
-	 * as specified via the ZEEK_PLUGIN_ACTIVATE enviroment variable. In other
-	 * words, it's \c true in standard mode and \c false in bare mode.
-	 *
-	 * @return True if all plugins have been loaded successfully. If one
-	 * fails to load, the method stops there without loading any further ones
-	 * and returns false.
+	 * as specified via the ZEEK_PLUGIN_ACTIVATE environment variable.
 	 */
-	bool ActivateDynamicPlugins(bool all);
+	void ActivateDynamicPlugins(bool all);
 
 	/**
 	 * First-stage initializion of the manager. This is called early on
@@ -154,7 +153,7 @@ public:
 	 * path. The path can be the plugin directory itself, or any path
 	 * inside it.
 	 */
-	Plugin* LookupPluginByPath(std::string path);
+	Plugin* LookupPluginByPath(std::string_view path);
 
 	/**
 	 * Returns true if there's at least one plugin interested in a given
@@ -167,7 +166,7 @@ public:
 	bool HavePluginForHook(HookType hook) const
 		{
 		// Inline to avoid the function call.
-		return hooks[hook] != 0;
+		return hooks[hook] != nullptr;
 		}
 
 	/**
@@ -213,7 +212,7 @@ public:
 	void RequestEvent(EventHandlerPtr handler, Plugin* plugin);
 
 	/**
-	 * Register interest in the destruction of a BroObj instance. When Bro's
+	 * Register interest in the destruction of a Obj instance. When Bro's
 	 * reference counting triggers the objects destructor to run, the \a
 	 * HookBroObjDtor will be called.
 	 *
@@ -221,7 +220,7 @@ public:
 	 *
 	 * @param plugin The plugin expressing interest.
 	 */
-	void RequestBroObjDtor(BroObj* obj, Plugin* plugin);
+	void RequestBroObjDtor(Obj* obj, Plugin* plugin);
 
 	// Hook entry functions.
 
@@ -237,22 +236,25 @@ public:
 	 * if a plugin took over the file but had trouble loading it; and -1 if
 	 * no plugin was interested in the file at all.
 	 */
-	virtual int HookLoadFile(const Plugin::LoadType type, const string& file, const string& resolved);
+	virtual int HookLoadFile(const Plugin::LoadType type, const std::string& file, const std::string& resolved);
 
 	/**
 	 * Hook that filters calls to a script function/event/hook.
 	 *
 	 * @param func The function to be called.
 	 *
+	 * @param parent The frame in which the function is being called.
+	 *
 	 * @param args The function call's arguments; they may be modified by the
 	 * method.
 	 *
-	 * @return If a plugin handled the call, a Val with a +1 reference count
-	 * containing the result value to pass back to the interpreter (for void
-	 * functions and events, it may be any Val and must be ignored). If no
-	 * plugin handled the call, the method returns null.
+	 * @return If a plugin handled the call, a Val representing the result
+	 * to pass back to the interpreter (for void functions and events,
+	 * it may be any Val and must be ignored). If no plugin handled the call,
+	 * the method returns null.
 	 */
-	std::pair<bool, Val*> HookCallFunction(const Func* func, Frame *parent, val_list* args) const;
+	std::pair<bool, ValPtr>
+	HookCallFunction(const Func* func, zeek::detail::Frame* parent, Args* args) const;
 
 	/**
 	 * Hook that filters the queuing of an event.
@@ -384,8 +386,8 @@ public:
 	 *         if the event call should be skipped
 	 */
 	bool HookReporter(const std::string& prefix, const EventHandlerPtr event,
-	                  const Connection* conn, const val_list* addl, bool location,
-	                  const Location* location1, const Location* location2,
+	                  const Connection* conn, const ValPList* addl, bool location,
+	                  const zeek::detail::Location* location1, const zeek::detail::Location* location2,
 	                  bool time, const std::string& message);
 
 	/**
@@ -409,25 +411,29 @@ public:
 	static void RegisterBifFile(const char* plugin, bif_init_func c);
 
 private:
-	bool ActivateDynamicPluginInternal(const std::string& name, bool ok_if_not_found = false);
+	bool ActivateDynamicPluginInternal(const std::string& name, bool ok_if_not_found, std::vector<std::string>* errors);
 	void UpdateInputFiles();
 	void MetaHookPre(HookType hook, const HookArgumentList& args) const;
 	void MetaHookPost(HookType hook, const HookArgumentList& args, HookArgument result) const;
 
+	// Plugins that were explicitly requested to be activated, but failed to
+	// load at first.
+	std::set<std::string> requested_plugins;
+
 	 // All found dynamic plugins, mapping their names to base directory.
-	typedef std::map<std::string, std::string> dynamic_plugin_map;
+	using dynamic_plugin_map = std::map<std::string, std::string>;
 	dynamic_plugin_map dynamic_plugins;
 
 	// We temporarliy buffer scripts to load to get them to load in the
 	// right order.
-	typedef std::list<std::string> file_list;
+	using file_list = std::list<std::string>;
 	file_list scripts_to_load;
 
 	bool init;	// Flag indicating whether InitPreScript() has run yet.
 
 	// A hook list keeps pairs of plugin and priority interested in a
 	// given hook.
-	typedef std::list<std::pair<int, Plugin*> > hook_list;
+	using hook_list = std::list<std::pair<int, Plugin*>>;
 
 	// An array indexed by HookType. An entry is null if there's no hook
 	// of that type enabled.
@@ -446,8 +452,8 @@ private:
 	// even before the manager exists.
 	static plugin_list* ActivePluginsInternal();
 
-	typedef std::list<bif_init_func> bif_init_func_list;
-	typedef std::map<std::string, bif_init_func_list*> bif_init_func_map;
+	using bif_init_func_list = std::list<bif_init_func>;
+	using bif_init_func_map = std::map<std::string, bif_init_func_list*>;
 
 	// Returns a modifiable map of all bif files. This is a static method
 	// so that plugins can register their bifs even before the manager
@@ -476,6 +482,8 @@ std::list<T *> Manager::Components() const
 	return result;
 	}
 
+namespace detail {
+
 /**
  * Internal class used by bifcl-generated code to register its init functions at runtime.
  */
@@ -487,11 +495,20 @@ public:
 		}
 };
 
-}
+} // namespace detail
+} // namespace plugin
+
+extern plugin::Manager* plugin_mgr;
+
+} // namespace zeek
+
+namespace plugin {
+
+using Manager [[deprecated("Remove in v4.1. Use zeek::plugin::Manager.")]] = zeek::plugin::Manager;
+
+} // namespace plugin
 
 /**
  * The global plugin manager singleton.
  */
-extern plugin::Manager* plugin_mgr;
-
-#endif
+extern zeek::plugin::Manager*& plugin_mgr [[deprecated("Remove in v4.1. Use zeek::plugin_mgr.")]];
