@@ -1,22 +1,23 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
-
-#include "JSON.h"
-#include "3rdparty/rapidjson/include/rapidjson/internal/ieee754.h"
-#include "Desc.h"
-#include "threading/MsgThread.h"
+#include "zeek/threading/formatters/JSON.h"
 
 #ifndef __STDC_LIMIT_MACROS
 #define __STDC_LIMIT_MACROS
 #endif
 
-#include <sstream>
 #include <errno.h>
 #include <math.h>
 #include <stdint.h>
+#include <sstream>
 
-using namespace threading::formatter;
+#include <rapidjson/internal/ieee754.h>
+
+#include "zeek/Desc.h"
+#include "zeek/threading/MsgThread.h"
+
+namespace zeek::threading::formatter {
 
 bool JSON::NullDoubleWriter::Double(double d)
 	{
@@ -55,7 +56,7 @@ bool JSON::Describe(ODesc* desc, int num_fields, const Field* const * fields,
 	return true;
 	}
 
-bool JSON::Describe(ODesc* desc, Value* val, const string& name) const
+bool JSON::Describe(ODesc* desc, Value* val, const std::string& name) const
 	{
 	if ( desc->IsBinary() )
 		{
@@ -78,13 +79,14 @@ bool JSON::Describe(ODesc* desc, Value* val, const string& name) const
 	return true;
 	}
 
-threading::Value* JSON::ParseValue(const string& s, const string& name, TypeTag type, TypeTag subtype) const
+Value* JSON::ParseValue(const std::string& s, const std::string& name,
+                        TypeTag type, TypeTag subtype) const
 	{
 	GetThread()->Error("JSON formatter does not support parsing yet.");
 	return nullptr;
 	}
 
-void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const string& name) const
+void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const std::string& name) const
 	{
 	if ( ! val->present )
 		{
@@ -106,7 +108,6 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const string& name) c
 			break;
 
 		case TYPE_COUNT:
-		case TYPE_COUNTER:
 			writer.Uint64(val->val.uint_val);
 			break;
 
@@ -132,7 +133,7 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const string& name) c
 			if ( timestamps == TS_ISO8601 )
 				{
 				char buffer[40];
-				char buffer2[40];
+				char buffer2[48];
 				time_t the_time = time_t(floor(val->val.double_val));
 				struct tm t;
 
@@ -174,7 +175,8 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const string& name) c
 		case TYPE_FILE:
 		case TYPE_FUNC:
 			{
-			writer.String(json_escape_utf8(string(val->val.string_val.data, val->val.string_val.length)));
+			writer.String(util::json_escape_utf8(
+				              std::string(val->val.string_val.data, val->val.string_val.length)));
 			break;
 			}
 
@@ -182,7 +184,7 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const string& name) c
 			{
 			writer.StartArray();
 
-			for ( int idx = 0; idx < val->val.set_val.size; idx++ )
+			for ( bro_int_t idx = 0; idx < val->val.set_val.size; idx++ )
 				BuildJSON(writer, val->val.set_val.vals[idx]);
 
 			writer.EndArray();
@@ -193,7 +195,7 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const string& name) c
 			{
 			writer.StartArray();
 
-			for ( int idx = 0; idx < val->val.vector_val.size; idx++ )
+			for ( bro_int_t idx = 0; idx < val->val.vector_val.size; idx++ )
 				BuildJSON(writer, val->val.vector_val.vals[idx]);
 
 			writer.EndArray();
@@ -205,3 +207,5 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const string& name) c
 			break;
 		}
 	}
+
+} // namespace zeek::threading::formatter
