@@ -5,17 +5,6 @@
 
 #include "zeek/util.h"
 
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
-
 #ifdef HAVE_DARWIN
 #include <mach/task.h>
 #include <mach/mach_init.h>
